@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 from enum import Enum
-from typing import Optional
 
 from numpy import absolute
 
@@ -24,22 +23,20 @@ class DocEnum(Enum):
 
 
 class WaveType(DocEnum):
-    """Supported Wavetypes for the acoustic background field
-    """
+    """Supported Wavetypes for the acoustic background field"""
 
-    STANDING = 0, 'Plane standing wave'
-    TRAVELLING = 1, 'Plane travelling wave'
+    STANDING = 0, "Plane standing wave"
+    TRAVELLING = 1, "Plane travelling wave"
 
 
 class WrongWaveTypeError(Exception):
-    """ Exception for using the wrong Wave type
-    """
+    """Exception for using the wrong Wave type"""
 
     def __init__(self, msg=None, *args, **kwargs):
         if msg is None:
             msg = (
-                'Wavetype needs to be of type:'
-                f' {[t.name for t in WaveType]}'
+                "Wavetype needs to be of type:"
+                f" {[t.name for t in WaveType]}"
             )
         super().__init__(msg, *args, **kwargs)
 
@@ -55,53 +52,52 @@ class BackgroundField:
     """
 
     def __init__(
-        self, fluid: InviscidFluid,
+        self,
+        fluid: InviscidFluid,
         p_0: float,
         wave_type: WaveType = WaveType.STANDING,
-        position: Optional[float] = None,
+        position: None | float = None,
     ) -> None:
-        """Constructor Method
-        """
+        """Constructor Method"""
 
         self.fluid = fluid
 
         # Check position variable
         if position is None and wave_type == WaveType.STANDING:
             raise ValueError(
-                'Argument position needs to be given for a '
-                'standing wave.',
+                "Argument position needs to be given for a " "standing wave.",
             )
 
         # Independent Variables
-        self._p_0 = PassiveVariable(p_0, 'pressure amplitude p_0')
-        self._wave_type = PassiveVariable(wave_type, 'wave type')
-        self._position = PassiveVariable(position, 'scatterer position d')
+        self._p_0 = PassiveVariable(p_0, "pressure amplitude p_0")
+        self._wave_type = PassiveVariable(wave_type, "wave type")
+        self._position = PassiveVariable(position, "scatterer position d")
 
         # Dependent variables
         self._abs_pos = ActiveVariable(
             self._compute_abs_pos,
-            'absolute position in the standing wave',
+            "absolute position in the standing wave",
         )
 
         self._A = ActiveVariable(
             self._compute_A,
-            'velocity potential amplitude A',
+            "velocity potential amplitude A",
         )
         self._abs_A_squared = ActiveVariable(
             self._compute_abs_A_squared,
-            'squared absolute amplitude A',
+            "squared absolute amplitude A",
         )
         self._A_in = ActiveListVariable(
             self._compute_A_in,
-            'velocity potential amplitude A_n',
+            "velocity potential amplitude A_n",
         )
         self._E = ActiveVariable(
             self._compute_E,
-            'acoustic energy density E',
+            "acoustic energy density E",
         )
         self._I = ActiveVariable(
             self._compute_I,
-            'acoustic intensity I',
+            "acoustic intensity I",
         )
         # Dependencies
         self._abs_pos.is_computed_by(self.fluid._k_f, self._position)
@@ -133,12 +129,12 @@ class BackgroundField:
             self.fluid._c_f,
         )
 
-        log.debug(f'Creating {self}')
+        log.debug(f"Creating {self}")
 
     def __repr__(self) -> str:
         return (
-            f'BackgroundField(fluid={self.fluid}, p_0={self.p_0} '
-            f'wave_type={self.wave_type}, position={self.position})'
+            f"BackgroundField(fluid={self.fluid}, p_0={self.p_0} "
+            f"wave_type={self.wave_type}, position={self.position})"
         )
 
     # -------------------------------------------------------------------------
@@ -193,25 +189,22 @@ class BackgroundField:
 
     @property
     def abs_pos(self) -> float:
-        """Absolute position of the scatterer in the standing wave in [m] """
+        """Absolute position of the scatterer in the standing wave in [m]"""
         return self._abs_pos.value
 
     @property
     def A(self) -> complex:
-        """Amplitude of the pressure wave [Pa]
-        """
+        """Amplitude of the pressure wave [Pa]"""
         return self._A.value
 
     @property
     def abs_A_squared(self) -> float:
-        """:math:`A\\,\\text{conj}(A) = |A|^2` [Pa^2]
-        """
+        """:math:`A\\,\\text{conj}(A) = |A|^2` [Pa^2]"""
         return self._abs_A_squared.value
 
     @property
     def E_ac(self) -> float:
-        """Mean acoustic energy density [J/m^3]
-        """
+        """Mean acoustic energy density [J/m^3]"""
         if not isinstance(self.wave_type, WaveType):
             raise WrongWaveTypeError
 
@@ -219,13 +212,12 @@ class BackgroundField:
 
     @property
     def I_ac(self) -> float:
-        """Acoustic intensity / energy flux density [W/m^2]
-        """
+        """Acoustic intensity / energy flux density [W/m^2]"""
         if self.wave_type != WaveType.TRAVELLING:
             raise WrongWaveTypeError(
-                'The acoustic intensity is only '
-                'defined for: '
-                f'{WaveType.TRAVELLING}',
+                "The acoustic intensity is only "
+                "defined for: "
+                f"{WaveType.TRAVELLING}",
             )
         return self._I.value
 
@@ -237,7 +229,7 @@ class BackgroundField:
         return self.p_0 / (1j * self.omega * self.rho_f)
 
     def _compute_abs_A_squared(self) -> complex:
-        return absolute(self.A)**2
+        return absolute(self.A) ** 2
 
     # -------------------------------------------------------------------------
     # Wrapper Methods for Frequency
@@ -245,8 +237,7 @@ class BackgroundField:
 
     @property
     def f(self) -> float:
-        """ wrapper for :attr:`osaft.core.fluids.InviscidFluid.f`
-        """
+        """wrapper for :attr:`osaft.core.fluids.InviscidFluid.f`"""
         return self.fluid.f
 
     @f.setter
@@ -255,8 +246,7 @@ class BackgroundField:
 
     @property
     def omega(self) -> float:
-        """ wrapper for :attr:`osaft.core.fluids.InviscidFluid.omega`
-        """
+        """wrapper for :attr:`osaft.core.fluids.InviscidFluid.omega`"""
         return self.fluid.omega
 
     # -------------------------------------------------------------------------
@@ -265,8 +255,7 @@ class BackgroundField:
 
     @property
     def c_f(self) -> float:
-        """ wrapper for :attr:`osaft.core.fluids.InviscidFluid.c_f`
-        """
+        """wrapper for :attr:`osaft.core.fluids.InviscidFluid.c_f`"""
         return self.fluid.c_f
 
     @c_f.setter
@@ -275,8 +264,7 @@ class BackgroundField:
 
     @property
     def rho_f(self) -> float:
-        """ wrapper for :attr:`osaft.core.fluids.InviscidFluid.rho_f`
-        """
+        """wrapper for :attr:`osaft.core.fluids.InviscidFluid.rho_f`"""
         return self.fluid.rho_f
 
     @rho_f.setter
@@ -285,117 +273,112 @@ class BackgroundField:
 
     @property
     def eta_f(self) -> float:
-        """ wrapper for :attr:`osaft.core.fluids.ViscousFluid.eta_f`
-        """
+        """wrapper for :attr:`osaft.core.fluids.ViscousFluid.eta_f`"""
         try:
             return self.fluid.eta_f
         except AttributeError:
             log.warning(
-                'underlying fluid class of BackgroundField doesn\'t '
-                'have attribute eta_f',
+                "underlying fluid class of BackgroundField doesn't "
+                "have attribute eta_f",
             )
             return 0
 
     @eta_f.setter
     def eta_f(self, value) -> None:
-        if hasattr(self.fluid, 'eta_f'):
+        if hasattr(self.fluid, "eta_f"):
             self.fluid.eta_f = value
         else:
             log.warning(
-                'underlying fluid class of BackgroundField doesn\'t '
-                'have attribute eta_f',
+                "underlying fluid class of BackgroundField doesn't "
+                "have attribute eta_f",
             )
 
     @property
     def zeta_f(self) -> float:
-        """ wrapper for :attr:`osaft.core.fluids.ViscousFluid.zeta_f`
-        """
+        """wrapper for :attr:`osaft.core.fluids.ViscousFluid.zeta_f`"""
         try:
             return self.fluid.zeta_f
         except AttributeError:
             log.warning(
-                'underlying fluid class of BackgroundField doesn\'t '
-                'have attribute zeta_f',
+                "underlying fluid class of BackgroundField doesn't "
+                "have attribute zeta_f",
             )
             return 0
 
     @zeta_f.setter
     def zeta_f(self, value) -> None:
-        if hasattr(self.fluid, 'zeta_f'):
+        if hasattr(self.fluid, "zeta_f"):
             self.fluid.zeta_f = value
         else:
             log.warning(
-                'underlying fluid class of BackgroundField doesn\'t '
-                'have attribute zeta_f',
+                "underlying fluid class of BackgroundField doesn't "
+                "have attribute zeta_f",
             )
 
     @property
     def eta_p(self) -> float:
-        """ wrapper for :attr:`osaft.core.fluids.ViscoelasticFluid.eta_p`
-        """
+        """wrapper for :attr:`osaft.core.fluids.ViscoelasticFluid.eta_p`"""
         try:
             return self.fluid.eta_p
         except AttributeError:
             log.warning(
-                'underlying fluid class of BackgroundField doesn\'t '
-                'have attribute eta_p',
+                "underlying fluid class of BackgroundField doesn't "
+                "have attribute eta_p",
             )
             return 0
 
     @eta_p.setter
     def eta_p(self, value) -> None:
-        if hasattr(self.fluid, 'eta_p'):
+        if hasattr(self.fluid, "eta_p"):
             self.fluid.eta_p = value
         else:
             log.warning(
-                'underlying fluid class of BackgroundField doesn\'t '
-                'have attribute eta_p',
+                "underlying fluid class of BackgroundField doesn't "
+                "have attribute eta_p",
             )
 
     @property
     def zeta_p(self) -> float:
-        """ wrapper for :attr:`osaft.core.fluids.ViscoelasticFluid.zeta_p`
-        """
+        """wrapper for :attr:`osaft.core.fluids.ViscoelasticFluid.zeta_p`"""
         try:
             return self.fluid.zeta_p
         except AttributeError:
             log.warning(
-                'underlying fluid class of BackgroundField doesn\'t '
-                'have attribute zeta_p',
+                "underlying fluid class of BackgroundField doesn't "
+                "have attribute zeta_p",
             )
             return 0
 
     @zeta_p.setter
     def zeta_p(self, value) -> None:
-        if hasattr(self.fluid, 'zeta_p'):
+        if hasattr(self.fluid, "zeta_p"):
             self.fluid.zeta_p = value
         else:
             log.warning(
-                'underlying fluid class of BackgroundField doesn\'t '
-                'have attribute zeta_p',
+                "underlying fluid class of BackgroundField doesn't "
+                "have attribute zeta_p",
             )
 
     @property
     def lambda_M(self) -> float:
-        """ wrapper for :attr:`osaft.core.fluids.ViscoelasticFluid.lambda_M`
-        """
+        """wrapper for :attr:`osaft.core.fluids.ViscoelasticFluid.lambda_M`"""
         try:
             return self.fluid.lambda_M
         except AttributeError:
             log.warning(
-                'underlying fluid class of BackgroundField doesn\'t '
-                'have attribute lambda_M',
+                "underlying fluid class of BackgroundField doesn't "
+                "have attribute lambda_M",
             )
             return 0
 
     @lambda_M.setter
     def lambda_M(self, value) -> None:
-        if hasattr(self.fluid, 'lambda_M'):
+        if hasattr(self.fluid, "lambda_M"):
             self.fluid.lambda_M = value
         else:
             log.warning(
-                'underlying fluid class of BackgroundField doesn\'t '
-                'have attribute lambda_M',
+                "underlying fluid class of BackgroundField doesn't "
+                "have attribute lambda_M",
             )
 
     # -------------------------------------------------------------------------
@@ -404,26 +387,22 @@ class BackgroundField:
 
     @property
     def lambda_f(self) -> float:
-        """ wrapper for :attr:`osaft.core.fluids.InviscidFluid.lambda_f`
-        """
+        """wrapper for :attr:`osaft.core.fluids.InviscidFluid.lambda_f`"""
         return self.fluid.lambda_f
 
     @property
     def k_f(self) -> float:
-        """ wrapper for :attr:`osaft.core.fluids.InviscidFluid.k_f`
-        """
+        """wrapper for :attr:`osaft.core.fluids.InviscidFluid.k_f`"""
         return self.fluid.k_f
 
     @property
     def k_v(self) -> complex:
-        """ wrapper for :attr:`osaft.core.fluids.ViscousFluid.k_v`
-        """
+        """wrapper for :attr:`osaft.core.fluids.ViscousFluid.k_v`"""
         return self.fluid.k_v
 
     @property
     def kappa_f(self) -> float:
-        """ wrapper for :attr:`osaft.core.fluids.ViscousFluid.kappa_f`
-        """
+        """wrapper for :attr:`osaft.core.fluids.ViscousFluid.kappa_f`"""
         return self.fluid.kappa_f
 
     # -------------------------------------------------------------------------
@@ -443,13 +422,13 @@ class BackgroundField:
             return self._compute_A_in_standing(n)
 
     def _compute_A_in_travelling(self, n: int) -> complex:
-        return self.A * (2 * n + 1) * 1j ** n
+        return self.A * (2 * n + 1) * 1j**n
 
     def _compute_A_in_standing(self, n: int) -> complex:
         out = exp(1j * self.abs_pos * self.k_f)
         out += (-1) ** n * exp(-1j * self.abs_pos * self.k_f)
 
-        out *= self.A / 2 * (2 * n + 1) * 1j ** n
+        out *= self.A / 2 * (2 * n + 1) * 1j**n
         return out
 
     def A_in(self, n: int) -> complex:
@@ -464,9 +443,9 @@ class BackgroundField:
 
     def _compute_I(self) -> float:
         out = self.abs_A_squared * self.rho_f * self.fluid.c_f
-        out *= (self.fluid.k_f ** 2) / 2
+        out *= (self.fluid.k_f**2) / 2
         return out
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
