@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 from collections.abc import Callable, Iterable
-from typing import Optional
 
 import numpy as np
 from scipy import special
@@ -9,6 +10,7 @@ from scipy.special import exp1, factorial, lpmv
 from osaft import log
 
 # Often used NumPy and SciPy Functions and Classes
+NDArray = np.ndarray
 conj = np.conj
 exp = np.exp
 real = np.real
@@ -23,17 +25,18 @@ def full_range(*args: int) -> Iterable:
     """Returns the range including the end point.
 
     :param args: end point, start point (optional)
-    :raises: ValueError if more than 2 arguments are passed    """
+    :raises: ValueError if more than 2 arguments are passed"""
     if len(args) == 1:
         return range(args[0] + 1)
     elif len(args) == 2:
         return range(args[0], args[1] + 1)
     else:
-        raise ValueError('full_range takes one or two arguments.')
+        raise ValueError("full_range takes one or two arguments.")
 
 
 def cartesian_2_spherical_coordinates(
-    x: float, z: float,
+    x: float | NDArray,
+    z: float | NDArray,
 ) -> tuple[float, float]:
     """Transforms Cartesian coordinates `(x  z)` of an axisymmetric model into
     spherical coordinates `(r, theta)`. See `here
@@ -49,7 +52,8 @@ def cartesian_2_spherical_coordinates(
 
 
 def spherical_2_cartesian_coordinates(
-    r: float, theta: float,
+    r: float | NDArray,
+    theta: float | NDArray,
 ) -> tuple[float, float]:
     """Transforms spherical coordinates `(r  theta)` of an axisymmetric model
     into Cartesian coordinates `(x, z)`. See `here
@@ -114,11 +118,14 @@ def cartesian_2_spherical_vector(
 
 
 def clebsch_gordan_coefficient(
-    j1: int, m1: int,
-    j2: int, m2: int,
-    j: int, m: int,
+    j1: int,
+    m1: int,
+    j2: int,
+    m2: int,
+    j: int,
+    m: int,
 ) -> float:
-    """ Clebsch-Gordan coefficient for integer valued arguments.
+    """Clebsch-Gordan coefficient for integer valued arguments.
 
     :param j:
     :param m:
@@ -130,7 +137,7 @@ def clebsch_gordan_coefficient(
 
     for arg in [j1, m1, j2, m2, j, m]:
         if not isinstance(arg, int):
-            raise ValueError('Arguments need to be integer valued.')
+            raise ValueError("Arguments need to be integer valued.")
 
     if (m1 + m2) != m:
         return 0
@@ -140,33 +147,42 @@ def clebsch_gordan_coefficient(
         c = 0.0
         z = 0
         a = (
-            factorial(j1 + j2 - j) * factorial(j1 - j2 + j)
-            * factorial(-j1 + j2 + j) / factorial(j1 + j2 + j + 1.0)
-        )**0.5
+            factorial(j1 + j2 - j)
+            * factorial(j1 - j2 + j)
+            * factorial(-j1 + j2 + j)
+            / factorial(j1 + j2 + j + 1.0)
+        ) ** 0.5
         b = (
-            factorial(j1 + m1) * factorial(j1 - m1) * factorial(j2 + m2)
-            * factorial(j2 - m2) * factorial(j + m) * factorial(j - m)
-        )**0.5
+            factorial(j1 + m1)
+            * factorial(j1 - m1)
+            * factorial(j2 + m2)
+            * factorial(j2 - m2)
+            * factorial(j + m)
+            * factorial(j - m)
+        ) ** 0.5
         while z < (j1 - m1 + 3):
             denominator = (
-                factorial(z) * factorial(j1 + j2 - j - z)
+                factorial(z)
+                * factorial(j1 + j2 - j - z)
                 * factorial(j1 - m1 - z)
                 * factorial(j2 + m2 - z)
                 * factorial(j - j2 + m1 + z)
                 * factorial(j - j1 - m2 + z)
             )
-            numerator = (-1)**float(z + j1 - j2 + m)
+            numerator = (-1) ** float(z + j1 - j2 + m)
             if denominator != 0:
                 c += numerator / denominator
             z += 1
-        return (-1.0)**(j1 - j2 + m) * (2.0 * j + 1.0)**0.5 * a * b * c
+        return (-1.0) ** (j1 - j2 + m) * (2.0 * j + 1.0) ** 0.5 * a * b * c
 
 
 def integrate(
-    func: Callable[[float], float], lower: float, upper: float,
+    func: Callable[[float], float],
+    lower: float,
+    upper: float,
     rel_eps: float = 1e-6,
 ) -> tuple[float, float]:
-    """ Integrates :attr:`func` between :attr:`lower` and :attr:`upper`
+    """Integrates :attr:`func` between :attr:`lower` and :attr:`upper`
     Scipy's QUADPACK implementation `quad()
     <https://docs.scipy.org/doc/scipy/reference/generated/scipy.integrate
     .quad.html>`__ .
@@ -179,30 +195,35 @@ def integrate(
 
     # Logging
     log.debug(
-        'Relative precision goal for integration has been passed.'
-        'Adaptive integration scheme is chosen.',
+        "Relative precision goal for integration has been passed."
+        "Adaptive integration scheme is chosen.",
     )
     # Integration
     integral, abs_err = quad(
-        func, lower, upper, epsabs=0,
-        epsrel=rel_eps, limit=200,
+        func,
+        lower,
+        upper,
+        epsabs=0,
+        epsrel=rel_eps,
+        limit=200,
     )
     log.debug(
-        f'Integral = {integral},'
-        f'absolute error estimation = {abs_err}\n',
+        f"Integral = {integral}," f"absolute error estimation = {abs_err}\n",
     )
     return integral, abs_err
 
 
 def integrate_osc(
-    func: Callable[[float], float], lower: float, upper: float,
+    func: Callable[[float], float],
+    lower: float,
+    upper: float,
     boundary_layer: float,
-    viscous_wavelength: Optional[float] = None,
+    viscous_wavelength: None | float = None,
     resolution: int = 4,
     roi_factor: int = 5,
     rel_eps: float = 1e-6,
 ) -> tuple[float, float]:
-    """ Special purpose integrator for oscillating integrals that
+    """Special purpose integrator for oscillating integrals that
     integrates :attr:`func` between :attr:`lower` and  :attr:`upper`. This
     method employs Scipy's QUADPACK implementation `quad()
     <https://docs.scipy.org/doc/scipy/reference/generated/
@@ -241,13 +262,17 @@ def integrate_osc(
 
     # Integrate
     integral, abs_err = quad(
-        func, lower, upper, epsabs=0, epsrel=rel_eps,
-        points=points, limit=limit,
+        func,
+        lower,
+        upper,
+        epsabs=0,
+        epsrel=rel_eps,
+        points=points,
+        limit=limit,
     )
 
     log.debug(
-        f'Integral = {integral},'
-        f'absolute error estimation = {abs_err}\n',
+        f"Integral = {integral}," f"absolute error estimation = {abs_err}\n",
     )
     return integral, abs_err
 
@@ -272,24 +297,25 @@ def xexpexp1(z: complex, N: int = 20) -> complex:
 
 
 class LegendreFunctions:
-    """ This class gathers all reoccurring Legendre Functions necessary for
-     the osaft package. """
+    """This class gathers all reoccurring Legendre Functions necessary for
+    the osaft package."""
 
     @staticmethod
-    def cos_poly(theta: float, coefficients: np.array) -> np.ndarray:
-        """ Sum of Legendre polynomial with a cosine function as an argument
+    def cos_poly(theta: float, coefficients: NDArray) -> NDArray:
+        """Sum of Legendre polynomial with a cosine function as an argument
 
         :param theta: angle
         :param coefficients: coefficients of the polynomial
         """
         return np.polynomial.legendre.legval(
-            cos(theta), coefficients,
+            cos(theta),
+            coefficients,
             tensor=False,
         )
 
     @staticmethod
     def cos_monomial(degree: int, theta: float, coefficient: complex) -> float:
-        """ Returns a single term of Legendre Cosine series
+        """Returns a single term of Legendre Cosine series
 
         :param degree: degree of the polynomial to be returned
         :param theta:  angle
@@ -298,8 +324,8 @@ class LegendreFunctions:
         return coefficient * lpmv(0, degree, cos(theta))
 
     @staticmethod
-    def first_cos_poly(theta: float, coefficients: np.array) -> np.ndarray:
-        """ Sum of associate Legendre Polynomial of order one with a cosine
+    def first_cos_poly(theta: float, coefficients: NDArray) -> NDArray:
+        """Sum of associate Legendre Polynomial of order one with a cosine
         as input variable
 
         :param theta: angle
@@ -307,19 +333,17 @@ class LegendreFunctions:
         """
         degrees = len(coefficients)
         return np.sum(
-            [
-                coefficients[n] * lpmv(1, n, cos(theta))
-                for n in range(degrees)
-            ],
+            [coefficients[n] * lpmv(1, n, cos(theta)) for n in range(degrees)],
             axis=0,
         )
 
     @staticmethod
     def first_cos_monomial(
-        degree: int, theta: float,
+        degree: int,
+        theta: float,
         coefficient: complex,
     ) -> float:
-        """ Returns a single term of associate Legendre Cosine series of the
+        """Returns a single term of associate Legendre Cosine series of the
         first order
 
         :param degree: degree of the term
@@ -330,8 +354,8 @@ class LegendreFunctions:
 
 
 class BesselFunctions:
-    """ This class gathers all reoccurring spherical hankel and bessel
-    functions necessary for the osaft package. """
+    """This class gathers all reoccurring spherical hankel and bessel
+    functions necessary for the osaft package."""
 
     @staticmethod
     def _a0_d2(n: int, z: complex) -> complex:
@@ -347,13 +371,14 @@ class BesselFunctions:
 
     @staticmethod
     def _a1_d3(n: int, z: complex) -> complex:
-        return (-n**2 - n - 6) / z**2 + 1
+        return (-(n**2) - n - 6) / z**2 + 1
 
     @staticmethod
     def _a0_d4(n: int, z: complex) -> complex:
         return (
-            n * (n - 1) * (6 + n * (n - 5)) / z ** 4
-            + (-2 * n * (n - 1) - 8) / z ** 2 + 1
+            n * (n - 1) * (6 + n * (n - 5)) / z**4
+            + (-2 * n * (n - 1) - 8) / z**2
+            + 1
         )
 
     @staticmethod
@@ -372,9 +397,12 @@ class BesselFunctions:
     def _a1_d5(n: int, z: complex) -> complex:
         return -(
             (
-                n * (1 + n) * (58 + n + n**2) - 2 * n * (1 + n) * z**2 + z**4
+                n * (1 + n) * (58 + n + n**2)
+                - 2 * n * (1 + n) * z**2
+                + z**4
                 - 20 * (-6 + z**2)
-            ) / z**4
+            )
+            / z**4
         )
 
     @staticmethod
@@ -404,10 +432,10 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d2(n, z) * cls.besselj(n, z)
-            + cls._a1_d2(n, z) * cls.besselj(n + 1, z)
-        )
+        return cls._a0_d2(n, z) * cls.besselj(n, z) + cls._a1_d2(
+            n,
+            z,
+        ) * cls.besselj(n + 1, z)
 
     @classmethod
     def d3_besselj(cls, n: int, z: complex) -> complex:
@@ -417,10 +445,10 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d3(n, z) * cls.besselj(n, z)
-            + cls._a1_d3(n, z) * cls.besselj(n + 1, z)
-        )
+        return cls._a0_d3(n, z) * cls.besselj(n, z) + cls._a1_d3(
+            n,
+            z,
+        ) * cls.besselj(n + 1, z)
 
     @classmethod
     def d4_besselj(cls, n: int, z: complex) -> complex:
@@ -430,10 +458,10 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d4(n, z) * cls.besselj(n, z)
-            + cls._a1_d4(n, z) * cls.besselj(n + 1, z)
-        )
+        return cls._a0_d4(n, z) * cls.besselj(n, z) + cls._a1_d4(
+            n,
+            z,
+        ) * cls.besselj(n + 1, z)
 
     @staticmethod
     def bessely(n: int, z: complex) -> complex:
@@ -462,10 +490,10 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d2(n, z) * cls.bessely(n, z)
-            + cls._a1_d2(n, z) * cls.bessely(n + 1, z)
-        )
+        return cls._a0_d2(n, z) * cls.bessely(n, z) + cls._a1_d2(
+            n,
+            z,
+        ) * cls.bessely(n + 1, z)
 
     @classmethod
     def d3_bessely(cls, n: int, z: complex) -> complex:
@@ -475,10 +503,10 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d3(n, z) * cls.bessely(n, z)
-            + cls._a1_d3(n, z) * cls.bessely(n + 1, z)
-        )
+        return cls._a0_d3(n, z) * cls.bessely(n, z) + cls._a1_d3(
+            n,
+            z,
+        ) * cls.bessely(n + 1, z)
 
     @classmethod
     def d4_bessely(cls, n: int, z: complex) -> complex:
@@ -488,10 +516,10 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d4(n, z) * cls.bessely(n, z)
-            + cls._a1_d4(n, z) * cls.bessely(n + 1, z)
-        )
+        return cls._a0_d4(n, z) * cls.bessely(n, z) + cls._a1_d4(
+            n,
+            z,
+        ) * cls.bessely(n + 1, z)
 
     @staticmethod
     def hankelh1(n: int, z: complex) -> complex:
@@ -520,10 +548,10 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d2(n, z) * cls.hankelh1(n, z)
-            + cls._a1_d2(n, z) * cls.hankelh1(n + 1, z)
-        )
+        return cls._a0_d2(n, z) * cls.hankelh1(n, z) + cls._a1_d2(
+            n,
+            z,
+        ) * cls.hankelh1(n + 1, z)
 
     @classmethod
     def d3_hankelh1(cls, n: int, z: complex) -> complex:
@@ -533,10 +561,10 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d3(n, z) * cls.hankelh1(n, z)
-            + cls._a1_d3(n, z) * cls.hankelh1(n + 1, z)
-        )
+        return cls._a0_d3(n, z) * cls.hankelh1(n, z) + cls._a1_d3(
+            n,
+            z,
+        ) * cls.hankelh1(n + 1, z)
 
     @classmethod
     def d4_hankelh1(cls, n: int, z: complex) -> complex:
@@ -546,10 +574,10 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d4(n, z) * cls.hankelh1(n, z)
-            + cls._a1_d4(n, z) * cls.hankelh1(n + 1, z)
-        )
+        return cls._a0_d4(n, z) * cls.hankelh1(n, z) + cls._a1_d4(
+            n,
+            z,
+        ) * cls.hankelh1(n + 1, z)
 
     @classmethod
     def d5_hankelh1(cls, n: int, z: complex) -> complex:
@@ -559,10 +587,10 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d5(n, z) * cls.hankelh1(n, z)
-            + cls._a1_d5(n, z) * cls.hankelh1(n + 1, z)
-        )
+        return cls._a0_d5(n, z) * cls.hankelh1(n, z) + cls._a1_d5(
+            n,
+            z,
+        ) * cls.hankelh1(n + 1, z)
 
     @staticmethod
     def hankelh2(n: int, z: complex) -> complex:
@@ -591,10 +619,10 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d2(n, z) * cls.hankelh2(n, z)
-            + cls._a1_d2(n, z) * cls.hankelh2(n + 1, z)
-        )
+        return cls._a0_d2(n, z) * cls.hankelh2(n, z) + cls._a1_d2(
+            n,
+            z,
+        ) * cls.hankelh2(n + 1, z)
 
     @classmethod
     def d3_hankelh2(cls, n: int, z: complex) -> complex:
@@ -604,10 +632,10 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d3(n, z) * cls.hankelh2(n, z)
-            + cls._a1_d3(n, z) * cls.hankelh2(n + 1, z)
-        )
+        return cls._a0_d3(n, z) * cls.hankelh2(n, z) + cls._a1_d3(
+            n,
+            z,
+        ) * cls.hankelh2(n + 1, z)
 
     @classmethod
     def d4_hankelh2(cls, n: int, z: complex) -> complex:
@@ -617,10 +645,10 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d4(n, z) * cls.hankelh2(n, z)
-            + cls._a1_d4(n, z) * cls.hankelh2(n + 1, z)
-        )
+        return cls._a0_d4(n, z) * cls.hankelh2(n, z) + cls._a1_d4(
+            n,
+            z,
+        ) * cls.hankelh2(n + 1, z)
 
     @classmethod
     def d5_hankelh2(cls, n: int, z: complex) -> complex:
@@ -630,14 +658,17 @@ class BesselFunctions:
         :param n: order
         :param z: argument
         """
-        return (
-            cls._a0_d5(n, z) * cls.hankelh2(n, z)
-            + cls._a1_d5(n, z) * cls.hankelh2(n + 1, z)
-        )
+        return cls._a0_d5(n, z) * cls.hankelh2(n, z) + cls._a1_d5(
+            n,
+            z,
+        ) * cls.hankelh2(n + 1, z)
 
     @classmethod
     def adaptive_derivative_besselj(
-            cls, n: int, z: complex, i: int = 0,
+        cls,
+        n: int,
+        z: complex,
+        i: int = 0,
     ) -> complex:
         """Returns the value of the `i`-th derivative of the spherical
         Bessel function of the first kind of order `n`. The
@@ -653,7 +684,10 @@ class BesselFunctions:
 
     @classmethod
     def adaptive_derivative_bessely(
-            cls, n: int, z: complex, i: int = 0,
+        cls,
+        n: int,
+        z: complex,
+        i: int = 0,
     ) -> complex:
         """Returns the value of the `i`-th derivative of the spherical
         Bessel function of the second kind of order `n`. The coefficients
@@ -669,7 +703,10 @@ class BesselFunctions:
 
     @classmethod
     def adaptive_derivative_hankelh1(
-            cls, n: int, z: complex, i: int = 0,
+        cls,
+        n: int,
+        z: complex,
+        i: int = 0,
     ) -> complex:
         """Returns the value of the `i`-th derivative of the spherical
         Hankel function of order `n`. The coefficients for the derivative
@@ -685,7 +722,10 @@ class BesselFunctions:
 
     @classmethod
     def adaptive_derivative_hankelh2(
-            cls, n: int, z: complex, i: int = 0,
+        cls,
+        n: int,
+        z: complex,
+        i: int = 0,
     ) -> complex:
         """Returns the value of the `i`-th derivative of the spherical
         Hankel function of order `n`. The coefficients for the derivative
@@ -701,25 +741,34 @@ class BesselFunctions:
 
     @classmethod
     def _adaptive_derivative(
-        cls, func: Callable[[int, complex], complex],
-        i: int, n: int, z: complex,
+        cls,
+        func: Callable[[int, complex], complex],
+        i: int,
+        n: int,
+        z: complex,
     ) -> complex:
         out = 0
         for j in np.arange(i + 1):
             out += cls._adaptive_coefficient(
-                i, j, n, z,
+                i,
+                j,
+                n,
+                z,
             ) * func(n + j, z)
         return out
 
     @classmethod
     def _adaptive_coefficient(
-        cls, i: int, j: int,
-        n: int, z: complex,
+        cls,
+        i: int,
+        j: int,
+        n: int,
+        z: complex,
     ) -> complex:
         if j > i or j < 0:
             out = 0
         elif j == i:
-            out = (-1)**i
+            out = (-1) ** i
         elif j == 0 and i == 1:
             out = n / z
         else:
@@ -730,5 +779,5 @@ class BesselFunctions:
         return out
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
