@@ -19,5 +19,5 @@ class BasePlot:
             return ax.get_figure(), ax
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
