@@ -1,10 +1,14 @@
+from __future__ import annotations
+
 import concurrent.futures
-from typing import Any, Union
+from typing import Any
 
 import numpy as np
 
 from osaft.solutions.base_arf import BaseARF
 
+NDArray = np.ndarray
+
 
 class ARFData:
     """Container for plotting data for ARF plots
@@ -15,10 +19,10 @@ class ARFData:
 
     _instances = 0
     _line_styles = [
-        '-',
-        '--',
-        ':',
-        '-.',
+        "-",
+        "--",
+        ":",
+        "-.",
         (0, (5, 10)),
         (0, (3, 1, 1, 1)),
         (0, (1, 2)),
@@ -44,7 +48,7 @@ class ARFData:
         self._instance = ARFData._instances
         ARFData._instances += 1
 
-    def compute_arf(self, attr_name: str, values: np.ndarray) -> None:
+    def compute_arf(self, attr_name: str, values: NDArray) -> None:
 
         if self.multicore:
             self._arf = self._compute_arf_multi_process(attr_name, values)
@@ -53,21 +57,26 @@ class ARFData:
         self._plotting = self._arf
 
     def _compute_arf_single_process(
-        self, attr_name: str, values: np.ndarray,
-    ) -> np.ndarray:
+        self,
+        attr_name: str,
+        values: NDArray,
+    ) -> NDArray:
         arf = []
         for val in values:
             arf.append(
                 self._change_attr_and_compute_arf(
                     self.sol,
-                    attr_name, val,
+                    attr_name,
+                    val,
                 ),
             )
         return np.asarray(arf)
 
     def _compute_arf_multi_process(
-        self, attr_name: str, values: np.ndarray,
-    ) -> np.ndarray:
+        self,
+        attr_name: str,
+        values: NDArray,
+    ) -> NDArray:
         """Computes the ARF using multiple processes
 
         The ARF is computes using the `ProcessPoolExecutor` which will
@@ -80,7 +89,9 @@ class ARFData:
             arf = np.fromiter(
                 executor.map(
                     self._change_attr_and_compute_arf,
-                    sols, attr_names, values,
+                    sols,
+                    attr_names,
+                    values,
                 ),
                 dtype=float,
             )
@@ -88,7 +99,9 @@ class ARFData:
 
     @staticmethod
     def _change_attr_and_compute_arf(
-        sol: BaseARF, attr_name: str, val: Any,
+        sol: BaseARF,
+        attr_name: str,
+        val: Any,
     ) -> float:
         """Changes the attribute `attr_name` to value `val`
 
@@ -102,22 +115,22 @@ class ARFData:
         setattr(sol, attr_name, val)
         return sol.compute_arf()
 
-    def normalize_arf(self, norm: np.ndarray) -> None:
+    def normalize_arf(self, norm: NDArray) -> None:
         self._norm_arf = self._arf / norm
         self._plotting = self._norm_arf
 
     @property
-    def line_style(self) -> Union[str, tuple[int, tuple[int]]]:
+    def line_style(self) -> str | tuple[int, tuple[int]]:
 
         L = len(ARFData._line_styles)
         return ARFData._line_styles[self._instance % L]
 
     @property
-    def arf(self) -> np.ndarray:
+    def arf(self) -> NDArray:
         return self._arf
 
     @property
-    def plotting(self) -> np.ndarray:
+    def plotting(self) -> NDArray:
         return self._plotting
 
     @property
@@ -125,5 +138,5 @@ class ARFData:
         return self.sol.name
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
