@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 from collections.abc import Callable
-from typing import Optional
 
 import numpy as np
 from matplotlib import colors
@@ -16,26 +17,28 @@ from mpl_toolkits.axes_grid1 import make_axes_locatable
 from osaft.core.functions import pi, sqrt
 from osaft.plotting.scattering.base_plotter import BaseScatteringPlotter
 
+NDArray = np.ndarray
+
 
 class TriangulationPlotter(BaseScatteringPlotter):
     """Base class for plotting first order solutions such as the acoustic
     scattering fields and particle vibrations.
 
-    :param particle: if `True`, plot of the particle, else plot of the fluid
+    :param is_scatterer: if `True`, plot of the scatterer,
+        else plot of the fluid
     :param cmap: colormap passed to matplotlib
     :param div_cmap: diverging colormap passed to matplotlib
     """
 
     def __init__(
         self,
-        particle: bool,
-        cmap: str = 'winter',
-        div_cmap: str = 'Spectral_r',
+        is_scatterer: bool,
+        cmap: str = "winter",
+        div_cmap: str = "Spectral_r",
     ) -> None:
-        """Constructor method
-        """
+        """Constructor method"""
         # Call to parent class
-        super().__init__(particle)
+        super().__init__(is_scatterer)
 
         # Color map
         self.cmap = cmap
@@ -46,27 +49,32 @@ class TriangulationPlotter(BaseScatteringPlotter):
     # -------------------------------------------------------------------------
 
     def plot(
-            self,
-            X: np.ndarray,
-            Y: np.ndarray,
-            C: np.ndarray,
-            radius: Optional[float],
-            symmetric: bool,
-            tripcolor: bool,
-            cbar_label: str,
-            use_diverging_cmap: bool,
-            ax: Optional[plt.Axes],
-            **kwargs
+        self,
+        X: NDArray,
+        Y: NDArray,
+        C: NDArray,
+        radius: None | float,
+        symmetric: bool,
+        tripcolor: bool,
+        cbar_label: str,
+        use_diverging_cmap: bool,
+        ax: None | plt.Axes,
+        **kwargs,
     ) -> [
-        Optional[plt.Figure], plt.Axes, TriMesh, Optional[Colorbar],
+        None | plt.Figure,
+        plt.Axes,
+        TriMesh,
+        None | Colorbar,
         tri.Triangulation,
     ]:
         """Plot for the scattering field
 
         Plots the scattering field using `tripcolor
-        <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.tripcolor.html>`_
+        <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot
+        .tripcolor.html>`_
         or `tricontourf
-        <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.tricontourf.html>`_
+        <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot
+        .tricontourf.html>`_
         from Matplotlib.
 
         :param X: array of x-coordinates
@@ -74,10 +82,10 @@ class TriangulationPlotter(BaseScatteringPlotter):
         :param C: array of the values
         :param radius: radius for masked triangulation
         :param symmetric: if true the plot is symmetric w.r.t. the x-axis
-        :param tripcolor: if `True` tripcolor plot, if `False` tricontourf plot
+        :param tripcolor: if ``True`` tripcolor plot
         :param cbar_label: label for the color bar
         :param use_diverging_cmap: use the specified diverging cmap
-        :param ax: axes
+        :param ax: if ``ax`` is passed, plot will be drawn on ``ax``
         """
         # Create figure and axis
         fig, ax = self._create_figure(ax)
@@ -87,14 +95,14 @@ class TriangulationPlotter(BaseScatteringPlotter):
         if symmetric:
             C = np.concatenate([C, C])
 
-        if 'cmap' not in kwargs.keys():
+        if "cmap" not in kwargs.keys():
             cmap = self.div_cmap if use_diverging_cmap else self.cmap
-            kwargs['cmap'] = cmap
+            kwargs["cmap"] = cmap
 
         # Plot tripcolor or tricontourf plot
         if tripcolor:
-            if 'shading' not in kwargs.keys():
-                kwargs['shading'] = 'gouraud'
+            if "shading" not in kwargs.keys():
+                kwargs["shading"] = "gouraud"
 
             trc = ax.tripcolor(triang, C, **kwargs)
         else:
@@ -114,26 +122,23 @@ class TriangulationPlotter(BaseScatteringPlotter):
         cbar_label: str,
         use_diverging_cmap: bool,
         radius: float,
-        animate_meth: Callable[
-            [float],
-            tuple[np.ndarray, np.ndarray, np.ndarray],
-        ],
-        C_norm: np.ndarray,
-        ax: Optional[plt.Axes],
+        animate_meth: Callable[[float], tuple[NDArray, NDArray, NDArray]],
+        C_norm: NDArray,
+        ax: None | plt.Axes,
         **kwargs,
     ) -> FuncAnimation:
         """Animates tricontourf and tripcolor plot
 
         :param frames: number of frames
         :param interval: interval between frames in ms
-        :param tripcolor: if `True` tripcolor, else tricontourf
+        :param tripcolor: if ``True`` tripcolor, else tricontourf
         :param symmetric: if the symmetric part of plot shall be plotted
         :param cbar_label: label for the color bar
         :param use_diverging_cmap: use as :attr:`div_cmap`
         :param animate_meth: function that returns speed for given phase
         :param C_norm: absolute values of the field to be plotted
         :param radius: radius
-        :param ax: axes object
+        :param ax: if ``ax`` is passed, plot will be drawn on ``ax``
         :param kwargs: passed through to tripcolor or tricontourf
         """
         # Get Coordinates
@@ -147,8 +152,18 @@ class TriangulationPlotter(BaseScatteringPlotter):
 
         # Initial plot
         fig, ax, triplot, cbar, triang = self.plot(
-            Z, X, C_norm, radius, symmetric, tripcolor,
-            cbar_label, use_diverging_cmap, ax, vmin=vmin, vmax=vmax, **kwargs,
+            Z,
+            X,
+            C_norm,
+            radius,
+            symmetric,
+            tripcolor,
+            cbar_label,
+            use_diverging_cmap,
+            ax,
+            vmin=vmin,
+            vmax=vmax,
+            **kwargs,
         )
 
         if use_diverging_cmap:
@@ -157,10 +172,10 @@ class TriangulationPlotter(BaseScatteringPlotter):
             # one
             cbar.remove()
 
-            norm = colors.TwoSlopeNorm(vmin=vmin, vcenter=0., vmax=vmax)
+            norm = colors.TwoSlopeNorm(vmin=vmin, vcenter=0.0, vmax=vmax)
             cm = ScalarMappable(norm, self.div_cmap)
             divider = make_axes_locatable(ax)
-            cax = divider.append_axes('right', '8%', pad='8%')
+            cax = divider.append_axes("right", "8%", pad="8%")
             cbar = fig.colorbar(cm, cax=cax, label=cbar_label)
 
             fig.tight_layout()
@@ -176,19 +191,30 @@ class TriangulationPlotter(BaseScatteringPlotter):
                 interval=interval,
                 blit=False,
                 fargs=(
-                    frames, triplot, annotation, animate_meth, symmetric,
+                    frames,
+                    triplot,
+                    annotation,
+                    animate_meth,
+                    symmetric,
                     use_diverging_cmap,
                 ),
             )
         else:
             anim = FuncAnimation(
-                fig, self._animation_func_tricontourf,
+                fig,
+                self._animation_func_tricontourf,
                 frames=frames,
                 interval=interval,
                 blit=False,
                 fargs=(
-                    frames, ax, triplot, triang, annotation, animate_meth,
-                    symmetric, use_diverging_cmap,
+                    frames,
+                    ax,
+                    triplot,
+                    triang,
+                    annotation,
+                    animate_meth,
+                    symmetric,
+                    use_diverging_cmap,
                 ),
             )
 
@@ -198,12 +224,12 @@ class TriangulationPlotter(BaseScatteringPlotter):
     # Triangulation
     # -------------------------------------------------------------------------
 
-    @ staticmethod
+    @staticmethod
     def triangulation(
-        X: np.ndarray,
-        Y: np.ndarray,
+        X: NDArray,
+        Y: NDArray,
         symmetric: bool,
-    ) -> tuple[np.ndarray, np.ndarray, tri.Triangulation]:
+    ) -> tuple[NDArray, NDArray, tri.Triangulation]:
         """Creates the triangulation
 
         Creates triangulation of points with coordinates (X[i], Y[i])
@@ -221,15 +247,15 @@ class TriangulationPlotter(BaseScatteringPlotter):
 
     def masked_triangulation(
         self,
-        X: np.ndarray,
-        Y: np.ndarray,
+        X: NDArray,
+        Y: NDArray,
         symmetric: bool,
-        radius: Optional[float] = None,
+        radius: None | float = None,
     ) -> tri.Triangulation:
         """Creates the masked triangulation
 
         Creates the masked triangulation of points with coordinates
-        (X[i],Y[i]). If `radius` is passed points inside radius are masked.
+        (X[i],Y[i]). If ``radius`` is passed points inside radius are masked.
 
         :param X: array of x-coordinates
         :param Y: array of y-coordinates
@@ -237,13 +263,10 @@ class TriangulationPlotter(BaseScatteringPlotter):
         :param radius: radius of the particle
         """
         X, Y, triangs = self.triangulation(X, Y, symmetric=symmetric)
-        if not self.particle:
-            mask = (
-                np.hypot(
-                    X[triangs.triangles].mean(axis=1),
-                    Y[triangs.triangles].mean(axis=1),
-                ) < radius
-            )
+        if not self.is_scatterer:
+            X = X[triangs.triangles].mean(axis=1)
+            Y = Y[triangs.triangles].mean(axis=1)
+            mask = np.hypot(X, Y) < radius
             triangs.set_mask(mask)
         return triangs
 
@@ -257,10 +280,7 @@ class TriangulationPlotter(BaseScatteringPlotter):
         n_frames: int,
         triplot: TriMesh,
         annotation: Annotation,
-        animate_meth: Callable[
-            [float],
-            tuple[np.ndarray, np.ndarray, np.ndarray],
-        ],
+        animate_meth: Callable[[float], tuple[NDArray, NDArray, NDArray]],
         symmetric: bool,
         use_diverging_cmap: bool,
     ) -> TriMesh:
@@ -291,19 +311,16 @@ class TriangulationPlotter(BaseScatteringPlotter):
         return triplot
 
     def _animation_func_tricontourf(
-            self,
-            frame: int,
-            n_frames: int,
-            ax: plt.Axes,
-            triplot: TriMesh,
-            triang: Triangulation,
-            annotation: Annotation,
-            animate_meth: Callable[
-                [float],
-                tuple[np.ndarray, np.ndarray, np.ndarray],
-            ],
-            symmetric: bool,
-            use_diverging_cmap: bool,
+        self,
+        frame: int,
+        n_frames: int,
+        ax: plt.Axes,
+        triplot: TriMesh,
+        triang: Triangulation,
+        annotation: Annotation,
+        animate_meth: Callable[[float], tuple[NDArray, NDArray, NDArray]],
+        symmetric: bool,
+        use_diverging_cmap: bool,
     ) -> TriMesh:
         """Animation function for tricontourf plot
 
@@ -354,10 +371,10 @@ class TriangulationPlotter(BaseScatteringPlotter):
         self,
         fig: plt.Figure,
         ax: plt.Axes,
-        radius: Optional[float],
+        radius: None | float,
         cbar_mappable: ScalarMappable,
         cbar_label: str,
-    ) -> Optional[Colorbar]:
+    ) -> None | Colorbar:
         """Post-processes tricontourf/tripcolor plot
 
         add ticks, labels, circle, color bar, and color bar label
@@ -372,13 +389,13 @@ class TriangulationPlotter(BaseScatteringPlotter):
         cbar = self._add_colorbar(fig, ax, cbar_mappable, cbar_label)
         return cbar
 
-    @ staticmethod
+    @staticmethod
     def _add_colorbar(
         fig: plt.Figure,
         ax: plt.Axes,
         mappable: ScalarMappable,
         label: str,
-    ) -> Optional[Colorbar]:
+    ) -> None | Colorbar:
         """Add color bar to figure
 
         :param fig: figure
@@ -388,7 +405,7 @@ class TriangulationPlotter(BaseScatteringPlotter):
             fig = plt.gcf()  # pragma: no cover
 
         divider = make_axes_locatable(ax)
-        cax = divider.append_axes('right', '8%', pad='8%')
+        cax = divider.append_axes("right", "8%", pad="8%")
         cbar = fig.colorbar(mappable, cax=cax, label=label)
         return cbar
 
@@ -402,7 +419,7 @@ class TriangulationPlotter(BaseScatteringPlotter):
         """
         ax.autoscale(True, tight=True)
         old_left, old_right = ax.get_xlim()
-        if self.particle:
+        if self.is_scatterer:
             left = 1.05 * old_left
             right = 1.05 * old_right
         else:
@@ -412,5 +429,5 @@ class TriangulationPlotter(BaseScatteringPlotter):
         ax.set_ylim(left, right)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
