@@ -36,63 +36,70 @@ class BaseGeneralARF(ABC):
     x_v: complex
 
     def __init__(self) -> None:
-        """Constructor method
-        """
+        """Constructor method"""
 
         self._D_n = ActiveListVariable(
             self._compute_D_n,
-            'ARF coefficient D_n',
+            "ARF coefficient D_n",
         )
 
         self._S_1n = ActiveListVariable(
             self._compute_S_1n,
-            'ARF coefficient S_{1n}',
+            "ARF coefficient S_{1n}",
         )
 
         self._S_2n = ActiveListVariable(
             self._compute_S_2n,
-            'ARF coefficient S_{2n}',
+            "ARF coefficient S_{2n}",
         )
 
         self._S_3n = ActiveListVariable(
             self._compute_S_3n,
-            'ARF coefficient S_{3n}',
+            "ARF coefficient S_{3n}",
         )
 
         self._S_4n = ActiveListVariable(
             self._compute_S_4n,
-            'ARF coefficient S_{4n}',
+            "ARF coefficient S_{4n}",
         )
 
         self._S_5n = ActiveListVariable(
             self._compute_S_5n,
-            'ARF coefficient S_{5n}',
+            "ARF coefficient S_{5n}",
         )
 
         self._S_6n = ActiveListVariable(
             self._compute_S_6n,
-            'ARF coefficient S_{6n}',
+            "ARF coefficient S_{6n}",
         )
 
         self._S_7n = ActiveListVariable(
             self._compute_S_7n,
-            'ARF coefficient S_{7n}',
+            "ARF coefficient S_{7n}",
         )
 
         self._S_8n = ActiveListVariable(
             self._compute_S_8n,
-            'ARF coefficient S_{8n}',
+            "ARF coefficient S_{8n}",
         )
 
         self._S_9n = ActiveListVariable(
             self._compute_S_9n,
-            'ARF coefficient S_{9n}',
+            "ARF coefficient S_{9n}",
         )
 
         self._D_n.is_computed_by(
-            self._alpha_n, self._beta_n, self._S_1n, self._S_2n,
-            self._S_3n, self._S_4n, self._S_5n, self._S_6n, self._S_7n,
-            self._S_8n, self._S_9n,
+            self._alpha_n,
+            self._beta_n,
+            self._S_1n,
+            self._S_2n,
+            self._S_3n,
+            self._S_4n,
+            self._S_5n,
+            self._S_6n,
+            self._S_7n,
+            self._S_8n,
+            self._S_9n,
         )
         self._S_1n.is_computed_by(self._x, self._x_v)
         self._S_2n.is_computed_by(self._x, self._x_v)
@@ -124,8 +131,14 @@ class BaseGeneralARF(ABC):
             prefactor = (n + 1) / (2 * n + 1) / (2 * n + 3)
             return prefactor * (term_1 + term_2)
 
-        F1 = -3 / 2 * pi * self.rho_f * sum(
-            [term(n) for n in full_range(self.N_max)],
+        F1 = (
+            -3
+            / 2
+            * pi
+            * self.rho_f
+            * sum(
+                [term(n) for n in full_range(self.N_max)],
+            )
         )
         return F1.real
 
@@ -164,7 +177,7 @@ class BaseGeneralARF(ABC):
     # -------------------------------------------------------------------------
 
     def D_n(self, n: int) -> complex:
-        """ coefficient :math:`D_{n}`
+        """coefficient :math:`D_{n}`
 
         :param n: order
         """
@@ -206,7 +219,7 @@ class BaseGeneralARF(ABC):
             tmp1 = Bf.d1_hankelh2(n, x_con)
             tmp2 = Bf.d1_hankelh2(n + 1, x_con)
         else:
-            raise ValueError(f'l can only be 1 or 2 nor {l}')
+            raise ValueError(f"l can only be 1 or 2 nor {l}")
 
         out = x_con * Bf.d1_hankelh1(n, x) * tmp1
         out += x * Bf.d1_hankelh1(n + 1, x) * tmp2
@@ -259,7 +272,7 @@ class BaseGeneralARF(ABC):
             tmp1 = Bf.d1_hankelh2(n, x_con)
             tmp2 = Bf.d1_hankelh2(n + 1, x_con)
         else:
-            raise ValueError(f'l can only be 1 or 2 nor {l}')
+            raise ValueError(f"l can only be 1 or 2 nor {l}")
 
         out = (n + 1) * x_con**2 / self.x_v**2 * tmp1
         out *= Bf.hankelh1(n, self.x_v)
@@ -300,9 +313,9 @@ class BaseGeneralARF(ABC):
             tmp1 = Bf.d1_hankelh2(n, self.x)
             tmp2 = Bf.d1_hankelh2(n + 1, self.x)
         else:
-            raise ValueError(f'l can only be 1 or 2 nor {l}')
+            raise ValueError(f"l can only be 1 or 2 nor {l}")
 
-        out = - (n + 1) * self.x**2 / self.x_v**2 * tmp2
+        out = -(n + 1) * self.x**2 / self.x_v**2 * tmp2
         out *= Bf.hankelh2(n + 1, x_v_con)
 
         out += self.x * Bf.d1_hankelh2(n, x_v_con) * tmp1
@@ -343,12 +356,12 @@ class BaseGeneralARF(ABC):
 
     @cache
     def J_nm_j(
-            self,
-            x1: complex,
-            x2: complex,
-            n: int,
-            m: int,
-            j: int,
+        self,
+        x1: complex,
+        x2: complex,
+        n: int,
+        m: int,
+        j: int,
     ) -> complex:
         """Integral :math:`J_{nm}^{(j)}`
 
@@ -365,12 +378,12 @@ class BaseGeneralARF(ABC):
 
     @cache
     def H_nm_j(
-            self,
-            x1: complex,
-            x2: complex,
-            n: int,
-            m: int,
-            j: int,
+        self,
+        x1: complex,
+        x2: complex,
+        n: int,
+        m: int,
+        j: int,
     ) -> complex:
         """Integral :math:`H_{nm}^{(j)}`
 
@@ -384,12 +397,12 @@ class BaseGeneralARF(ABC):
 
     @cache
     def H_nm_j_sum(
-            self,
-            x1: complex,
-            x2: complex,
-            n: int,
-            m: int,
-            j: int,
+        self,
+        x1: complex,
+        x2: complex,
+        n: int,
+        m: int,
+        j: int,
     ) -> complex:
         """Coefficient :math:`H_{nm}^{(j)}`
 
@@ -412,12 +425,12 @@ class BaseGeneralARF(ABC):
         return complex(out)
 
     def _J_nm_j_sum(
-            self,
-            x1: complex,
-            x2: complex,
-            n: int,
-            m: int,
-            j: int,
+        self,
+        x1: complex,
+        x2: complex,
+        n: int,
+        m: int,
+        j: int,
     ) -> complex:
         """Integrate J_nm using sum of Bessel functions
 
@@ -427,14 +440,14 @@ class BaseGeneralARF(ABC):
         :param m: :math:`m`
         :param j: :math:`j`
         """
-        arg_1 = mpmath.mpc(- 1j * x1 + 1j * x2.conjugate())
-        arg_2 = mpmath.mpc(- 1j * x1 - 1j * x2.conjugate())
+        arg_1 = mpmath.mpc(-1j * x1 + 1j * x2.conjugate())
+        arg_2 = mpmath.mpc(-1j * x1 - 1j * x2.conjugate())
         out = mpmath.mpc(0)
         for k in full_range(n):
             for q in full_range(m):
                 M = 2 + k + q + j
                 term = mpmath.expint(M, arg_1)
-                term -= (- 1) ** (q + m) * mpmath.expint(M, arg_2)
+                term -= (-1) ** (q + m) * mpmath.expint(M, arg_2)
                 term *= mpmath.mpc(x1 ** (-(k + 1)))
                 term *= mpmath.mpc(x2.conjugate() ** (-(q + 1)))
                 term *= self.B_kq(k, q, m, n)
@@ -442,12 +455,12 @@ class BaseGeneralARF(ABC):
         return complex(0.5 * out)
 
     def _J_nm_j_quadrature(
-            self,
-            x1: complex,
-            x2: complex,
-            n: int,
-            m: int,
-            j: int,
+        self,
+        x1: complex,
+        x2: complex,
+        n: int,
+        m: int,
+        j: int,
     ) -> complex:
         """Integrate J_nm using quadrature
 
@@ -457,6 +470,7 @@ class BaseGeneralARF(ABC):
         :param m: :math:`m`
         :param j: :math:`j`
         """
+
         def kernel(y: float) -> complex:
             out = y ** (-j) * Bf.hankelh1(n, x1 * y)
             out *= Bf.besselj(m, x2.conjugate() * y)
@@ -470,6 +484,7 @@ class BaseGeneralARF(ABC):
 
         :param kernel: kernel for integration
         """
+
         def real_kernel(y: float) -> float:
             return kernel(y).real
 
@@ -486,7 +501,7 @@ class BaseGeneralARF(ABC):
     # ------------------------------------------------------------------------
 
     def S_1n(self, n: int) -> complex:
-        """ coefficient :math:`S_{1n}`
+        """coefficient :math:`S_{1n}`
 
         :param n: order
         """
@@ -520,7 +535,7 @@ class BaseGeneralARF(ABC):
         return term_1 - term_2 + term_3 + term_4
 
     def S_2n(self, n: int) -> complex:
-        """ coefficient :math:`S_{2n}`
+        """coefficient :math:`S_{2n}`
 
         :param n: order
         """
@@ -548,7 +563,7 @@ class BaseGeneralARF(ABC):
         return n * (n + 2) * (term_1 - term_2 - term_3)
 
     def S_3n(self, n: int) -> complex:
-        """ coefficient :math:`S_{3n}`
+        """coefficient :math:`S_{3n}`
 
         :param n: order
         """
@@ -592,7 +607,7 @@ class BaseGeneralARF(ABC):
         return (n + 2) * (term_1 - term_2 + term_3 + term_4 + term_5 - term_6)
 
     def S_4n(self, n: int) -> complex:
-        """ coefficient :math:`S_{4n}`
+        """coefficient :math:`S_{4n}`
 
         :param n: order
         """
@@ -635,7 +650,7 @@ class BaseGeneralARF(ABC):
         return n * (term_1 + term_2 - term_3 + term_4 - term_5 + term_6)
 
     def S_5n(self, n: int) -> complex:
-        """ coefficient :math:`S_{5n}`
+        """coefficient :math:`S_{5n}`
 
         :param n: order
         """
@@ -671,7 +686,7 @@ class BaseGeneralARF(ABC):
         return term_1 - term_2 + term_3 + term_4
 
     def S_6n(self, n: int) -> complex:
-        """ coefficient :math:`S_{6n}`
+        """coefficient :math:`S_{6n}`
 
         :param n: order
         """
@@ -707,7 +722,7 @@ class BaseGeneralARF(ABC):
         return term_1 - term_2 + term_3 + term_4
 
     def S_7n(self, n: int) -> complex:
-        """ coefficient :math:`S_{7n}`
+        """coefficient :math:`S_{7n}`
 
         :param n: order
         """
@@ -752,7 +767,7 @@ class BaseGeneralARF(ABC):
         return n * (term_1 + term_2 - term_3 + term_4 + term_5 - term_6)
 
     def S_8n(self, n: int) -> complex:
-        """ coefficient :math:`S_{8n}`
+        """coefficient :math:`S_{8n}`
 
         :param n: order
         """
@@ -798,7 +813,7 @@ class BaseGeneralARF(ABC):
         return (n + 2) * (term_1 - term_2 + term_3 + term_4 - term_5 + term_6)
 
     def S_9n(self, n: int) -> complex:
-        """ coefficient :math:`S_{9n}`
+        """coefficient :math:`S_{9n}`
 
         :param n: order
         """
@@ -817,5 +832,5 @@ class BaseGeneralARF(ABC):
         return out * x * x_con / x_v**2
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
