@@ -13,7 +13,7 @@ class BaseScatteringDoinikov1994(BaseScattering, ABC):
     """
 
     def __init__(self, N_max: int) -> None:
-        """"init method"""
+        """ "init method"""
         super().__init__(N_max)
 
     def potential_coefficient(self, n: int) -> complex:
@@ -61,15 +61,13 @@ class BaseScatteringDoinikov1994(BaseScattering, ABC):
     @property
     @abstractmethod
     def k_f(self) -> complex:
-        """Returns the wave number in the fluid :math:`k_f` [1/m]
-        """
+        """Returns the wave number in the fluid :math:`k_f` [1/m]"""
         pass
 
     @property
     @abstractmethod
     def k_v(self) -> complex:
-        """Returns the viscous wave number in the fluid :math:`k_v` [1/m]
-            """
+        """Returns the viscous wave number in the fluid :math:`k_v` [1/m]"""
         pass
 
     @abstractmethod
@@ -97,5 +95,5 @@ class BaseScatteringDoinikov1994(BaseScattering, ABC):
         pass
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
