@@ -1,6 +1,7 @@
+from __future__ import annotations
+
 from abc import ABC
 from collections.abc import Iterable, Sequence
-from typing import Optional, Union
 
 import numpy as np
 
@@ -16,6 +17,8 @@ from osaft.solutions.basedoinikov2021.coefficientmatrix import (
     CoefficientMatrix,
 )
 
+NDArray = np.ndarray
+
 
 class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
     """Scattering field class for Doinikov (viscous fluid-elastic sphere; 2021)
@@ -32,48 +35,56 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
     """
 
     def __init__(
-            self, f: Union[Frequency, float],
-            R_0: Union[Sphere, float],
-            rho_s: float, E_s: float, nu_s: float,
-            fluid: Union[ViscousFluid, ViscoelasticFluid],
-            p_0: float, wave_type: WaveType,
-            position: Optional[float] = None,
-            N_max: int = 5,
+        self,
+        f: Frequency | float,
+        R_0: Sphere | float,
+        rho_s: float,
+        E_s: float,
+        nu_s: float,
+        fluid: ViscousFluid | ViscoelasticFluid,
+        p_0: float,
+        wave_type: WaveType,
+        position: None | float = None,
+        N_max: int = 5,
     ) -> None:
-        """Constructor method
-        """
+        """Constructor method"""
 
         BaseScattering.__init__(self, N_max=N_max)
 
         CoefficientMatrix.__init__(
-            self, f=f, R_0=R_0,
-            rho_s=rho_s, E_s=E_s, nu_s=nu_s,
+            self,
+            f=f,
+            R_0=R_0,
+            rho_s=rho_s,
+            E_s=E_s,
+            nu_s=nu_s,
             fluid=fluid,
-            p_0=p_0, wave_type=wave_type, position=position,
+            p_0=p_0,
+            wave_type=wave_type,
+            position=position,
         )
 
-        log.info('Create ScatteringField')
+        log.info("Create ScatteringField")
 
         # Dependent variables - Coefficients
         self._a = ActiveListVariable(
             self._compute_a,
-            'radial fluid coefficients a_n',
+            "radial fluid coefficients a_n",
         )
         self._a.is_computed_by(self._list_matrix_M_n, self._list_vector_n)
         self._a_hat = ActiveListVariable(
             self._compute_a_hat,
-            'radial particle coefficients a_hat_n',
+            "radial particle coefficients a_hat_n",
         )
         self._a_hat.is_computed_by(self._list_matrix_M_n, self._list_vector_n)
         self._b = ActiveListVariable(
             self._compute_b,
-            'tangential fluid coefficients b_n',
+            "tangential fluid coefficients b_n",
         )
         self._b.is_computed_by(self._list_matrix_M_n, self._list_vector_n)
         self._b_hat = ActiveListVariable(
             self._compute_b_hat,
-            'tangential particle coefficients '
-            'b_hat_n',
+            "tangential particle coefficients " "b_hat_n",
         )
         self._b_hat.is_computed_by(self._list_matrix_M_n, self._list_vector_n)
 
@@ -84,10 +95,10 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
 
     def __repr__(self):
         return (
-            f'ScatteringField({self.f}, {self.R_0}, {self.rho_s}, '
-            f'{self.E_s}), {self.nu_s}. {self.rho_f}, {self.c_f}, '
-            f'{self.eta_f}, {self.zeta_f}, {self.p_0}, {self.wave_type}, '
-            f'{self.field.position}, {self.N_max})'
+            f"ScatteringField({self.f}, {self.R_0}, {self.rho_s}, "
+            f"{self.E_s}), {self.nu_s}. {self.rho_f}, {self.c_f}, "
+            f"{self.eta_f}, {self.zeta_f}, {self.p_0}, {self.wave_type}, "
+            f"{self.field.position}, {self.N_max})"
         )
 
     # -------------------------------------------------------------------------
@@ -96,11 +107,11 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
 
     def radial_particle_displacement(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
-        mode: Optional[int] = None,
-    ) -> Union[complex, np.ndarray]:
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
+        mode: None | int = None,
+    ) -> complex | NDArray:
         """First-order radial particle displacements [m]
 
         :param r: radial coordinate [m]
@@ -111,15 +122,19 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
         """
 
         def coefficients(
-            l: int, x: Union[complex, np.ndarray],
-        ) -> Union[complex, np.ndarray]:
+            l: int,
+            x: complex | NDArray,
+        ) -> complex | NDArray:
             term1 = self.k_l * self.a_hat(l) * Bf.d1_besselj(l, self.k_l * x)
             term2 = (l + 1) * l * self.b_hat(l) * Bf.besselj(l, self.k_t * x)
             term2 /= x
             return term1 - term2
 
         r, theta, t = InputHandler.handle_input(
-            r, theta, t, self.R_0,
+            r,
+            theta,
+            t,
+            self.R_0,
             inside_sphere=True,
         )
 
@@ -127,12 +142,12 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
 
     def radial_particle_velocity(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
-        mode: Optional[int] = None,
-    ) -> Union[complex, np.ndarray]:
-        """ First-order radial particle velocity [m/s]
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
+        mode: None | int = None,
+    ) -> complex | NDArray:
+        """First-order radial particle velocity [m/s]
 
         :param r: radial coordinate [m]
         :param theta: tangential coordinate [rad]
@@ -145,12 +160,12 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
 
     def tangential_particle_displacement(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
-        mode: Optional[int] = None,
-    ) -> Union[complex, np.ndarray]:
-        """ First-order tangential particle displacements [m]
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
+        mode: None | int = None,
+    ) -> complex | NDArray:
+        """First-order tangential particle displacements [m]
 
         :param r: radial coordinate [m]
         :param theta: tangential coordinate [rad]
@@ -160,32 +175,38 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
         """
 
         def coefficients(
-            l: int, x: Union[complex, np.ndarray],
-        ) -> Union[complex, np.ndarray]:
-            term1 = self.a_hat(l) * Bf.besselj(l, self.k_l * x)
+            l: int,
+            x: complex | NDArray,
+        ) -> complex | NDArray:
+            term1 = Bf.besselj(l, self.k_l * x)
             term2 = Bf.besselj(l, self.k_t * x)
             term2 += self.k_t * x * Bf.d1_besselj(l, self.k_t * x)
-            term2 *= self.b_hat(l)
-            return (term1 - term2) / x
+            return (self.a_hat(l) * term1 - self.b_hat(l) * term2) / x
 
         r, theta, t = InputHandler.handle_input(
-            r, theta, t, self.R_0,
+            r,
+            theta,
+            t,
+            self.R_0,
             inside_sphere=True,
         )
 
         return self.tangential_mode_superposition(
-            coefficients, r, theta, t,
+            coefficients,
+            r,
+            theta,
+            t,
             mode,
         )
 
     def tangential_particle_velocity(
         self,
-        r: Union[float, Sequence],
-        theta: Union[float, Sequence],
-        t: Union[float, Sequence],
-        mode: Optional[int] = None,
-    ) -> Union[complex, np.ndarray]:
-        """ First-order tangential particle displacements [m]
+        r: float | Sequence,
+        theta: float | Sequence,
+        t: float | Sequence,
+        mode: None | int = None,
+    ) -> complex | NDArray:
+        """First-order tangential particle displacements [m]
 
         :param r: radial coordinate [m]
         :param theta: tangential coordinate [rad]
@@ -272,20 +293,17 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
 
     @property
     def range_N_max(self) -> Iterable:
-        """Returns ``range(0, N_max + 1)``
-        """
+        """Returns ``range(0, N_max + 1)``"""
         return self._range_N_max.value
 
     @property
     def range_1_N_max(self) -> Iterable:
-        """Returns ``range(1, N_max + 1)``
-        """
+        """Returns ``range(1, N_max + 1)``"""
         return self._range_1_N_max.value
 
     @property
     def range_2_N_max(self) -> Iterable:
-        """Returns ``range(2, N_max + 1)``
-        """
+        """Returns ``range(2, N_max + 1)``"""
         return self._range_2_N_max.value
 
     def _compute_range_N_max(self) -> Iterable:
@@ -314,7 +332,11 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
         return inviscid - viscous
 
     def d_V_r(
-        self, n: int, r: float, scattered: bool, incident: bool,
+        self,
+        n: int,
+        r: float,
+        scattered: bool,
+        incident: bool,
     ) -> complex:
         """:math:`\\partial_r V_{rn}(r)` [m/s]
 
@@ -333,8 +355,9 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
             return self.d_V_r_sc(n, r)
         else:
             raise ValueError(
-                'Neither scattered nor incident field has '
-                'been has been selected. Velocity field is zero.', )
+                "Neither scattered nor incident field has "
+                "been has been selected. Velocity field is zero.",
+            )
 
     def d_V_r_sc(self, n: int, r: float) -> complex:
         """:math:`\\partial_r V_{rn}^{sc}(r)` [m/s]
@@ -347,7 +370,7 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
         viscous = self.k_v * Bf.d1_hankelh1(n, self.k_v * r) * r
         viscous -= Bf.hankelh1(n, self.k_v * r)
         viscous *= n * (n + 1) * self.b(n) / r**2
-        inviscid = self.k_f ** 2 * self.a(n) * Bf.d2_hankelh1(n, self.k_f * r)
+        inviscid = self.k_f**2 * self.a(n) * Bf.d2_hankelh1(n, self.k_f * r)
         return inviscid - viscous
 
     def d_V_r_i(self, n: int, r: float) -> complex:
@@ -358,10 +381,14 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
         :param n: mode
         :param r: radial coordinate [m]
         """
-        return self.k_f ** 2 * self.A_in(n) * Bf.d2_besselj(n, self.k_f * r)
+        return self.k_f**2 * self.A_in(n) * Bf.d2_besselj(n, self.k_f * r)
 
     def d2_V_r(
-        self, n: int, r: float, scattered: bool, incident: bool,
+        self,
+        n: int,
+        r: float,
+        scattered: bool,
+        incident: bool,
     ) -> complex:
         """:math:`\\partial^2_r V_{rn}(r)` [m/s]
 
@@ -380,8 +407,9 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
             return self.d2_V_r_sc(n, r)
         else:
             raise ValueError(
-                'Neither scattered nor incident field has '
-                'been has been selected. Velocity field is zero.', )
+                "Neither scattered nor incident field has "
+                "been has been selected. Velocity field is zero.",
+            )
 
     def d2_V_r_i(self, n: int, r: float) -> complex:
         """:math:`\\partial^2_r V_{rn}^{i}(r)` [m/s]
@@ -391,7 +419,7 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
         :param n: mode
         :param r: radial coordinate [m]
         """
-        return self.k_f ** 3 * self.A_in(n) * Bf.d3_besselj(n, self.k_f * r)
+        return self.k_f**3 * self.A_in(n) * Bf.d3_besselj(n, self.k_f * r)
 
     def d2_V_r_sc(self, n: int, r: float) -> complex:
         """:math:`\\partial^2_r V_{rn}^{sc}(r)` [m/s]
@@ -401,10 +429,10 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
         :param n: mode
         :param r: radial coordinate [m]
         """
-        inviscid = self.k_f ** 3 * self.a(n) * Bf.d3_hankelh1(n, self.k_f * r)
-        viscous = 2 * Bf.hankelh1(n, self.k_v * r) / r ** 3
-        viscous -= 2 * self.k_v * Bf.d1_hankelh1(n, self.k_v * r) / r ** 2
-        viscous += self.k_v ** 2 * Bf.d2_hankelh1(n, self.k_v * r) / r
+        inviscid = self.k_f**3 * self.a(n) * Bf.d3_hankelh1(n, self.k_f * r)
+        viscous = 2 * Bf.hankelh1(n, self.k_v * r) / r**3
+        viscous -= 2 * self.k_v * Bf.d1_hankelh1(n, self.k_v * r) / r**2
+        viscous += self.k_v**2 * Bf.d2_hankelh1(n, self.k_v * r) / r
         viscous *= n * (n + 1) * self.b(n)
         return inviscid - viscous
 
@@ -423,7 +451,11 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
         return (inviscid - viscous) / r
 
     def d_V_theta(
-        self, n: int, r: float, scattered: bool, incident: bool,
+        self,
+        n: int,
+        r: float,
+        scattered: bool,
+        incident: bool,
     ) -> complex:
         """:math:`\\partial_r V_{\\theta n}(r)` [m/s]
 
@@ -444,11 +476,14 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
             return self.d_V_theta_sc(n, r)
         else:
             raise ValueError(
-                'Neither scattered nor incident field has '
-                'been has been selected. Velocity field is zero.', )
+                "Neither scattered nor incident field has "
+                "been has been selected. Velocity field is zero.",
+            )
 
     def d_V_theta_sc(
-        self, n: int, r: float,
+        self,
+        n: int,
+        r: float,
     ) -> complex:
         """:math:`\\partial_r V_{\\theta n}^{sc}(r)` [m/s]
 
@@ -478,7 +513,11 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
         return (d_nominator - nominator_div_r) / r
 
     def d2_V_theta(
-        self, n: int, r: float, scattered: bool, incident: bool,
+        self,
+        n: int,
+        r: float,
+        scattered: bool,
+        incident: bool,
     ) -> complex:
         """:math:`\\partial^2_r V_{\\theta n}(r)` [m/s]
 
@@ -499,8 +538,9 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
             return self.d2_V_theta_sc(n, r)
         else:
             raise ValueError(
-                'Neither scattered nor incident field has '
-                'been has been selected. Velocity field is zero.', )
+                "Neither scattered nor incident field has "
+                "been has been selected. Velocity field is zero.",
+            )
 
     def d2_V_theta_sc(self, n: int, r: float) -> complex:
         """:math:`\\partial^2_r V_{\\theta n}^{sc}(r)` [m/s]
@@ -510,11 +550,11 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
         :param n: mode
         :param r: radial coordinate [m]
         """
-        inviscid = self.k_f ** 2 * self.a(n) * Bf.d2_hankelh1(n, self.k_f * r)
+        inviscid = self.k_f**2 * self.a(n) * Bf.d2_hankelh1(n, self.k_f * r)
         viscous = 3 * Bf.d2_hankelh1(n, self.k_v * r)
         viscous += self.k_v * r * Bf.d3_hankelh1(n, self.k_v * r)
-        viscous *= self.b(n) * self.k_v ** 2
-        dd_nominator = (inviscid - viscous)
+        viscous *= self.b(n) * self.k_v**2
+        dd_nominator = inviscid - viscous
         return (dd_nominator - 2 * self.d_V_theta_sc(n, r)) / r
 
     def d2_V_theta_i(self, n: int, r: float) -> complex:
@@ -526,11 +566,15 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
         :param r: radial coordinate [m]
         """
         dd_nominator = self.A_in(n) * Bf.d2_besselj(n, self.k_f * r)
-        dd_nominator *= self.k_f ** 2
+        dd_nominator *= self.k_f**2
         return (dd_nominator - 2 * self.d_V_theta_i(n, r)) / r
 
     def phi(
-        self, n: int, r: float, scattered: bool, incident: bool,
+        self,
+        n: int,
+        r: float,
+        scattered: bool,
+        incident: bool,
     ) -> complex:
         """:math:`\\varphi_n(r)`
 
@@ -549,8 +593,9 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
             return self.phi_sc(n, r)
         else:
             raise ValueError(
-                'Neither scattered nor incident field has '
-                'been has been selected. Velocity field is zero.', )
+                "Neither scattered nor incident field has "
+                "been has been selected. Velocity field is zero.",
+            )
 
     def phi_sc(self, n: int, r: float) -> complex:
         """:math:`\\varphi_n^{sc}(r)`
@@ -573,7 +618,11 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
         return self.A_in(n) * Bf.besselj(n, self.k_f * r)
 
     def d_phi(
-        self, n: int, r: float, scattered: bool, incident: bool,
+        self,
+        n: int,
+        r: float,
+        scattered: bool,
+        incident: bool,
     ) -> complex:
         """:math:`\\partial_r \\varphi_n(r)`
 
@@ -592,8 +641,9 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
             return self.d_phi_sc(n, r)
         else:
             raise ValueError(
-                'Neither scattered nor incident field has '
-                'been has been selected. Velocity field is zero.', )
+                "Neither scattered nor incident field has "
+                "been has been selected. Velocity field is zero.",
+            )
 
     def d_phi_sc(self, n: int, r: float) -> complex:
         """:math:`\\partial_r \\varphi_n^{sc}(r)`
@@ -616,5 +666,5 @@ class BaseScatteringDoinikov2021(CoefficientMatrix, BaseScattering, ABC):
         return self.A_in(n) * self.k_f * Bf.d1_besselj(n, self.k_f * r)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
