@@ -1,4 +1,4 @@
-from typing import Union
+from __future__ import annotations
 
 from osaft import log
 from osaft.core.backgroundfields import WaveType
@@ -33,28 +33,45 @@ class BaseDoinikov1994Compressible(BaseDoinikov1994, BaseSolution):
     supported_wavetypes = [WaveType.STANDING, WaveType.TRAVELLING]
 
     def __init__(
-        self, f: Union[Frequency, float, int],
-        R_0: Union[Sphere, float, int],
-        rho_s: float, c_s: float, eta_s: float, zeta_s: float,
-        rho_f: float, c_f: float, eta_f: float, zeta_f: float,
-        p_0: float, wave_type: WaveType, position: float,
+        self,
+        f: Frequency | float | int,
+        R_0: Sphere | float | int,
+        rho_s: float,
+        c_s: float,
+        eta_s: float,
+        zeta_s: float,
+        rho_f: float,
+        c_f: float,
+        eta_f: float,
+        zeta_f: float,
+        p_0: float,
+        wave_type: WaveType,
+        position: float,
     ) -> None:
-        """Constructor method
-        """
+        """Constructor method"""
 
         # init of parent class
         BaseDoinikov1994.__init__(
             self,
-            f=f, R_0=R_0,
-            rho_f=rho_f, c_f=c_f, eta_f=eta_f, zeta_f=zeta_f,
-            p_0=p_0, wave_type=wave_type, position=position,
+            f=f,
+            R_0=R_0,
+            rho_f=rho_f,
+            c_f=c_f,
+            eta_f=eta_f,
+            zeta_f=zeta_f,
+            p_0=p_0,
+            wave_type=wave_type,
+            position=position,
         )
-        BaseSolution.__init__(self, 'Doinikov1994Compressible')
+        BaseSolution.__init__(self, "Doinikov1994Compressible")
 
         # Scatterer
         self.scatterer = ViscousFluid(
-            frequency=self.frequency, rho=rho_s, c=c_s,
-            eta_f=eta_s, zeta_f=zeta_s,
+            frequency=self.frequency,
+            rho=rho_s,
+            c=c_s,
+            eta_f=eta_s,
+            zeta_f=zeta_s,
         )
 
         if type(self) == BaseDoinikov1994Compressible:
@@ -63,82 +80,108 @@ class BaseDoinikov1994Compressible(BaseDoinikov1994, BaseSolution):
         # Dependent Variables
         self._rho_t = ActiveVariable(
             self._compute_rho_t,
-            'ratio of densities',
+            "ratio of densities",
         )
         self._rho_t.is_computed_by(self.fluid._rho_f, self.scatterer._rho_f)
 
     def __repr__(self):  # pragma: no cover
         return (
-            f'BaseDoinikov1994Rigid(f={self.f}, R_0={self.R_0}, '
-            f'rho_s={self.rho_s}, c_s={self.rho_f}, eta_s={self.rho_f}, ',
-            f'zeta_s={self.rho_f} ',
-            f'rho_f={self.rho_f}, c_f={self.c_f}, eta_f={self.eta_f}, '
-            f'zeta_f={self.zeta_f}, '
-            f'p_0={self.p_0}, position={self.position} {self.wave_type}, '
-            f'N_max={self.N_max})',
+            f"BaseDoinikov1994Rigid(f={self.f}, R_0={self.R_0}, "
+            f"rho_s={self.rho_s}, c_s={self.rho_f}, eta_s={self.rho_f}, ",
+            f"zeta_s={self.rho_f} ",
+            f"rho_f={self.rho_f}, c_f={self.c_f}, eta_f={self.eta_f}, "
+            f"zeta_f={self.zeta_f}, "
+            f"p_0={self.p_0}, position={self.position} {self.wave_type}, "
+            f"N_max={self.N_max})",
         )
 
     def __str__(self):  # pragma: no cover
-        out = 'Doinikovs\'s  (1994) model (viscous fluid-viscous sphere)'
-        out += ' with the following properties: \n'
-        out += SF.get_str_text('Frequency', 'f', self.f, 'Hz')
-        out += SF.get_str_text('Pressure', 'p_0', self.p_0, 'Pa')
-        out += SF.get_str_text('Wavetype', 'wave_type', self.wave_type, None)
+        out = "Doinikovs's  (1994) model (viscous fluid-viscous sphere)"
+        out += " with the following properties: \n"
+        out += SF.get_str_text("Frequency", "f", self.f, "Hz")
+        out += SF.get_str_text("Pressure", "p_0", self.p_0, "Pa")
+        out += SF.get_str_text("Wavetype", "wave_type", self.wave_type, None)
         out += SF.get_str_text(
-            'Position', 'd',
-            self.position, 'Pa',
+            "Position",
+            "d",
+            self.position,
+            "Pa",
         )
         out += SF.get_str_text(
-            'Wavelength', 'lambda',
-            self.field.lambda_f, 'm',
+            "Wavelength",
+            "lambda",
+            self.field.lambda_f,
+            "m",
         )
 
-        out += 'Fluid\n'
+        out += "Fluid\n"
         out += SF.get_str_text(
-            'Density', 'rho_f',
-            self.rho_f, 'kg/m^3',
+            "Density",
+            "rho_f",
+            self.rho_f,
+            "kg/m^3",
         )
         out += SF.get_str_text(
-            'Sound Speed', 'c_0',
-            self.c_f, 'm/s',
+            "Sound Speed",
+            "c_0",
+            self.c_f,
+            "m/s",
         )
         out += SF.get_str_text(
-            'Compressibility', 'kappa_f',
-            self.kappa_f, '1/Pa',
+            "Compressibility",
+            "kappa_f",
+            self.kappa_f,
+            "1/Pa",
         )
         out += SF.get_str_text(
-            'Shear viscosity', 'eta_f',
-            self.eta_f, '1/Pa',
+            "Shear viscosity",
+            "eta_f",
+            self.eta_f,
+            "1/Pa",
         )
         out += SF.get_str_text(
-            'Bulk viscosity', 'zeta_f',
-            self.zeta_f, '1/Pa',
+            "Bulk viscosity",
+            "zeta_f",
+            self.zeta_f,
+            "1/Pa",
         )
 
-        out += 'Particle\n'
+        out += "Particle\n"
         out += SF.get_str_text(
-            'Radius', 'R_0',
-            self.R_0, 'm',
+            "Radius",
+            "R_0",
+            self.R_0,
+            "m",
         )
         out += SF.get_str_text(
-            'Density', 'rho_s',
-            self.rho_s, 'kg/m^3',
+            "Density",
+            "rho_s",
+            self.rho_s,
+            "kg/m^3",
         )
         out += SF.get_str_text(
-            'Sound Speed', 'c_0',
-            self.c_s, 'm/s',
+            "Sound Speed",
+            "c_0",
+            self.c_s,
+            "m/s",
         )
         out += SF.get_str_text(
-            'Compressibility', 'kappa_s',
-            self.kappa_s, '1/Pa',
+            "Compressibility",
+            "kappa_s",
+            self.kappa_s,
+            "1/Pa",
         )
         out += SF.get_str_text(
-            'Shear viscosity', 'eta_s',
-            self.eta_s, '1/Pa',
+            "Shear viscosity",
+            "eta_s",
+            self.eta_s,
+            "1/Pa",
         )
         out += SF.get_str_text(
-            'Bulk viscosity', 'zeta_s',
-            self.zeta_s, '1/Pa',
+            "Bulk viscosity",
+            "zeta_s",
+            self.zeta_s,
+            "1/Pa",
         )
         return out
 
@@ -148,8 +191,7 @@ class BaseDoinikov1994Compressible(BaseDoinikov1994, BaseSolution):
 
     @property
     def rho_s(self) -> float:
-        """ Wraps to :attr:`osaft.core.solids.RigidSolid.rho_s`
-        """
+        """Wraps to :attr:`osaft.core.solids.RigidSolid.rho_s`"""
         return self.scatterer.rho_f
 
     @rho_s.setter
@@ -158,26 +200,22 @@ class BaseDoinikov1994Compressible(BaseDoinikov1994, BaseSolution):
 
     @property
     def kappa_s(self) -> float:
-        """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.kappa_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.ViscousFluid.kappa_f`"""
         return self.scatterer.kappa_f
 
     @property
     def k_s(self) -> complex:
-        """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.k_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.ViscousFluid.k_f`"""
         return self.scatterer.k_f
 
     @property
     def k_vs(self) -> complex:
-        """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.k_v`
-        """
+        """Wraps to :attr:`osaft.core.fluids.ViscousFluid.k_v`"""
         return self.scatterer.k_v
 
     @property
     def c_s(self) -> float:
-        """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.c_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.ViscousFluid.c_f`"""
         return self.scatterer.c_f
 
     @c_s.setter
@@ -186,8 +224,7 @@ class BaseDoinikov1994Compressible(BaseDoinikov1994, BaseSolution):
 
     @property
     def eta_s(self) -> float:
-        """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.eta_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.ViscousFluid.eta_f`"""
         return self.scatterer.eta_f
 
     @eta_s.setter
@@ -196,8 +233,7 @@ class BaseDoinikov1994Compressible(BaseDoinikov1994, BaseSolution):
 
     @property
     def zeta_s(self) -> float:
-        """ Wraps to :attr:`osaft.core.fluids.ViscousFluid.zeta_f`
-        """
+        """Wraps to :attr:`osaft.core.fluids.ViscousFluid.zeta_f`"""
         return self.scatterer.zeta_f
 
     @zeta_s.setter
@@ -205,5 +241,5 @@ class BaseDoinikov1994Compressible(BaseDoinikov1994, BaseSolution):
         self.scatterer.zeta_f = value
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
