@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Optional, Union
-
 import numpy as np
 
 from osaft import log
@@ -38,8 +36,9 @@ class ARF(ARFArbitraryRadius):
     """
 
     def __init__(
-        self, f: Union[Frequency, float, int],
-        R_0: Union[Sphere, float, int],
+        self,
+        f: Frequency | float | int,
+        R_0: Sphere | float | int,
         rho_s: float,
         rho_f: float,
         c_f: float,
@@ -47,7 +46,7 @@ class ARF(ARFArbitraryRadius):
         zeta_f: float,
         p_0: float,
         wave_type: WaveType,
-        position: Optional[float] = None,
+        position: None | float = None,
         long_wavelength: bool = False,
         small_boundary_layer: bool = False,
         large_boundary_layer: bool = False,
@@ -55,16 +54,27 @@ class ARF(ARFArbitraryRadius):
         background_streaming: bool = True,
         N_max: int = 5,
     ) -> None:
-        """Constructor method
-        """
+        """Constructor method"""
         # Call to init method of parent class
         super().__init__(
-            f, R_0, rho_s, rho_f, c_f, eta_f, zeta_f,
-            p_0, wave_type, position, long_wavelength,
+            f,
+            R_0,
+            rho_s,
+            rho_f,
+            c_f,
+            eta_f,
+            zeta_f,
+            p_0,
+            wave_type,
+            position,
+            long_wavelength,
             small_boundary_layer,
             large_boundary_layer,
-            fastened_sphere, background_streaming, N_max,
+            fastened_sphere,
+            background_streaming,
+            N_max,
         )
+
     # -------------------------------------------------------------------------
     # API
     # -------------------------------------------------------------------------
@@ -83,9 +93,9 @@ class ARF(ARFArbitraryRadius):
         self._check_option_combinations()
 
         log.info(
-            'Computing the ARF with Doinikov1994Rigid.\n'
-            f'x   = {self.x:+.4e} -> |x|   = {np.absolute(self.x):+.4e}\n'
-            f'x_v = {self.x_v:+.4e} -> |x_v| = {np.absolute(self.x_v):+.4e}',
+            "Computing the ARF with Doinikov1994Rigid.\n"
+            f"x   = {self.x:+.4e} -> |x|   = {np.absolute(self.x):+.4e}\n"
+            f"x_v = {self.x_v:+.4e} -> |x_v| = {np.absolute(self.x_v):+.4e}",
         )
 
         # Small Particle Solutions
@@ -122,8 +132,7 @@ class ARF(ARFArbitraryRadius):
         return out
 
     def _check_option_combinations(self):
-        """Checks if the combination of options is correct
-        """
+        """Checks if the combination of options is correct"""
         allowed_combinations = [
             # General
             (False, False, False, False, False),
@@ -139,18 +148,20 @@ class ARF(ARFArbitraryRadius):
             (True, False, True, True, True),
         ]
         combination = (
-            self.long_wavelength, self.small_boundary_layer,
-            self.large_boundary_layer, self.fastened_sphere,
+            self.long_wavelength,
+            self.small_boundary_layer,
+            self.large_boundary_layer,
+            self.fastened_sphere,
             self.background_streaming,
         )
         if combination not in allowed_combinations:
             raise ValueError(
-                f'The chosen combination {combination} for long_wavelength,'
-                'small_boundary_layer, large_boundary_layer,'
-                'fastened_sphere, background streaming is not allowed.'
-                f'Allowed options are: {allowed_combinations}',
+                f"The chosen combination {combination} for long_wavelength,"
+                "small_boundary_layer, large_boundary_layer,"
+                "fastened_sphere, background streaming is not allowed."
+                f"Allowed options are: {allowed_combinations}",
             )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
