@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Optional, Union
-
 from osaft import log
 from osaft.core.backgroundfields import WaveType
 from osaft.core.frequency import Frequency
@@ -32,26 +30,34 @@ class BaseDoinikov1994Rigid(BaseDoinikov1994, BaseSolution):
     supported_wavetypes = [WaveType.STANDING, WaveType.TRAVELLING]
 
     def __init__(
-        self, f: Union[Frequency, float],
-        R_0: Union[Sphere, float, int],
+        self,
+        f: Frequency | float,
+        R_0: Sphere | float | int,
         rho_s: float,
-        rho_f: float, c_f: float,
-        eta_f: float, zeta_f: float,
+        rho_f: float,
+        c_f: float,
+        eta_f: float,
+        zeta_f: float,
         p_0: float,
-        wave_type: Optional[WaveType] = WaveType.STANDING,
-        position: Optional[float] = None,
+        wave_type: None | WaveType = WaveType.STANDING,
+        position: None | float = None,
     ) -> None:
-        """Constructor method
-        """
+        """Constructor method"""
 
         # init of parent class
         BaseDoinikov1994.__init__(
             self,
-            f=f, R_0=R_0,
-            rho_f=rho_f, c_f=c_f, eta_f=eta_f, zeta_f=zeta_f,
-            p_0=p_0, wave_type=wave_type, position=position,
+            f=f,
+            R_0=R_0,
+            rho_f=rho_f,
+            c_f=c_f,
+            eta_f=eta_f,
+            zeta_f=zeta_f,
+            p_0=p_0,
+            wave_type=wave_type,
+            position=position,
         )
-        BaseSolution.__init__(self, 'Doinikov1994Rigid')
+        BaseSolution.__init__(self, "Doinikov1994Rigid")
 
         # Scatterer
         self.scatterer = RigidSolid(self.f, rho_s)
@@ -59,7 +65,7 @@ class BaseDoinikov1994Rigid(BaseDoinikov1994, BaseSolution):
         # Dependent Variables
         self._rho_t = ActiveVariable(
             self._compute_rho_t,
-            'ratio of densities',
+            "ratio of densities",
         )
         self._rho_t.is_computed_by(self.fluid._rho_f, self.scatterer._rho_s)
 
@@ -68,58 +74,76 @@ class BaseDoinikov1994Rigid(BaseDoinikov1994, BaseSolution):
 
     def __repr__(self):  # pragma: no cover
         return (
-            f'BaseDoinikov1994Rigid(f={self.f}, R_0={self.R_0}, '
-            f'rho_s={self.rho_s}, rho_f={self.rho_f}, c_f={self.c_f}, '
-            f'eta_f={self.eta_f}, zeta_f={self.zeta_f}, '
-            f'p_0={self.p_0}, position={self.position}, {self.wave_type}, '
-            f'N_max={self.N_max})'
+            f"BaseDoinikov1994Rigid(f={self.f}, R_0={self.R_0}, "
+            f"rho_s={self.rho_s}, rho_f={self.rho_f}, c_f={self.c_f}, "
+            f"eta_f={self.eta_f}, zeta_f={self.zeta_f}, "
+            f"p_0={self.p_0}, position={self.position}, {self.wave_type}, "
+            f"N_max={self.N_max})"
         )
 
     def __str__(self):  # pragma: no cover
-        out = 'Doinikov\'s  (1994) model (viscous fluid-rigid sphere)'
-        out += ' with the following properties: \n'
-        out += SF.get_str_text('Frequency', 'f', self.f, 'Hz')
-        out += SF.get_str_text('Pressure', 'p_0', self.p_0, 'Pa')
-        out += SF.get_str_text('Wavetype', 'wave_type', self.wave_type, None)
+        out = "Doinikov's  (1994) model (viscous fluid-rigid sphere)"
+        out += " with the following properties: \n"
+        out += SF.get_str_text("Frequency", "f", self.f, "Hz")
+        out += SF.get_str_text("Pressure", "p_0", self.p_0, "Pa")
+        out += SF.get_str_text("Wavetype", "wave_type", self.wave_type, None)
         out += SF.get_str_text(
-            'Position', 'd',
-            self.position, 'Pa',
+            "Position",
+            "d",
+            self.position,
+            "Pa",
         )
         out += SF.get_str_text(
-            'Wavelength', 'lambda',
-            self.field.lambda_f, 'm',
+            "Wavelength",
+            "lambda",
+            self.field.lambda_f,
+            "m",
         )
 
-        out += 'Fluid\n'
+        out += "Fluid\n"
         out += SF.get_str_text(
-            'Density', 'rho_f',
-            self.rho_f, 'kg/m^3',
+            "Density",
+            "rho_f",
+            self.rho_f,
+            "kg/m^3",
         )
         out += SF.get_str_text(
-            'Sound Speed', 'c_0',
-            self.c_f, 'm/s',
+            "Sound Speed",
+            "c_0",
+            self.c_f,
+            "m/s",
         )
         out += SF.get_str_text(
-            'Compressibility', 'kappa_f',
-            self.kappa_f, '1/Pa',
+            "Compressibility",
+            "kappa_f",
+            self.kappa_f,
+            "1/Pa",
         )
         out += SF.get_str_text(
-            'Shear viscosity', 'eta_f',
-            self.eta_f, '1/Pa',
+            "Shear viscosity",
+            "eta_f",
+            self.eta_f,
+            "1/Pa",
         )
         out += SF.get_str_text(
-            'Bulk viscosity', 'zeta_f',
-            self.zeta_f, '1/Pa',
+            "Bulk viscosity",
+            "zeta_f",
+            self.zeta_f,
+            "1/Pa",
         )
 
-        out += 'Particle\n'
+        out += "Particle\n"
         out += SF.get_str_text(
-            'Radius', 'R_0',
-            self.R_0, 'm',
+            "Radius",
+            "R_0",
+            self.R_0,
+            "m",
         )
         out += SF.get_str_text(
-            'Density', 'rho_s',
-            self.rho_s, 'kg/m^3',
+            "Density",
+            "rho_s",
+            self.rho_s,
+            "kg/m^3",
         )
         return out
 
@@ -129,8 +153,7 @@ class BaseDoinikov1994Rigid(BaseDoinikov1994, BaseSolution):
 
     @property
     def rho_s(self) -> float:
-        """ Wraps to :attr:`osaft.core.solids.RigidSolid.rho_s`
-        """
+        """Wraps to :attr:`osaft.core.solids.RigidSolid.rho_s`"""
         return self.scatterer.rho_s
 
     @rho_s.setter
@@ -138,5 +161,5 @@ class BaseDoinikov1994Rigid(BaseDoinikov1994, BaseSolution):
         self.scatterer.rho_s = value
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
