@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 from collections.abc import Callable
-from typing import Optional, Union
 
 import numpy as np
 
@@ -12,6 +13,8 @@ from osaft.core.geometries import Sphere
 from osaft.core.variable import ActiveVariable, PassiveVariable
 from osaft.solutions.doinikov2021viscous.scattering import ScatteringField
 
+NDArray = np.ndarray
+
 
 class StreamingField(ScatteringField):
     """Streaming field class for Doinikov (viscous fluid-elastic sphere; 2021)
@@ -35,51 +38,63 @@ class StreamingField(ScatteringField):
     """
 
     def __init__(
-            self, f: Union[Frequency, float],
-            R_0: Union[Sphere, float],
-            rho_s: float, E_s: float, nu_s: float,
-            rho_f: float, c_f: float,
-            eta_f: float, zeta_f: float,
-            p_0: float, wave_type: WaveType,
-            position: Optional[float] = None,
-            N_max: int = 5,
-            inf_factor: float = 60.0,
-            inf_type: Optional[str] = None,
-            integration_rel_eps: float = 1e-3,
+        self,
+        f: Frequency | float,
+        R_0: Sphere | float,
+        rho_s: float,
+        E_s: float,
+        nu_s: float,
+        rho_f: float,
+        c_f: float,
+        eta_f: float,
+        zeta_f: float,
+        p_0: float,
+        wave_type: WaveType,
+        position: None | float = None,
+        N_max: int = 5,
+        inf_factor: float = 60.0,
+        inf_type: None | str = None,
+        integration_rel_eps: float = 1e-3,
     ) -> None:
-        """Initialize class
-        """
+        """Initialize class"""
 
         # __init__ parent class
         ScatteringField.__init__(
             self,
-            f=f, R_0=R_0,
-            rho_s=rho_s, E_s=E_s, nu_s=nu_s,
-            rho_f=rho_f, c_f=c_f,
-            eta_f=eta_f, zeta_f=zeta_f,
-            p_0=p_0, wave_type=wave_type, position=position,
+            f=f,
+            R_0=R_0,
+            rho_s=rho_s,
+            E_s=E_s,
+            nu_s=nu_s,
+            rho_f=rho_f,
+            c_f=c_f,
+            eta_f=eta_f,
+            zeta_f=zeta_f,
+            p_0=p_0,
+            wave_type=wave_type,
+            position=position,
             N_max=N_max,
         )
 
         # Independent variables
-        self._inf_factor = PassiveVariable(inf_factor, 'infinity factor')
+        self._inf_factor = PassiveVariable(inf_factor, "infinity factor")
         self._inf_type = PassiveVariable(
             inf_type,
-            'infinity type',
+            "infinity type",
         )
 
         self._integration_rel_eps = PassiveVariable(
             integration_rel_eps,
-            'estimated integration error goal',
+            "estimated integration error goal",
         )
 
         # Dependent variables
         self._C_0 = ActiveVariable(
             self._compute_C_0,
-            'integration constants C_0',
+            "integration constants C_0",
         )
 
-        self._inf = ActiveVariable(self._compute_inf, 'infinity')
+        self._inf = ActiveVariable(self._compute_inf, "infinity")
 
         # Dependencies
         self._C_0.is_computed_by(
@@ -93,8 +108,10 @@ class StreamingField(ScatteringField):
         )
 
         self._inf.is_computed_by(
-            self._inf_type, self._inf_factor,
-            self.sphere._R_0, self.fluid._delta,
+            self._inf_type,
+            self._inf_factor,
+            self.sphere._R_0,
+            self.fluid._delta,
         )
 
     # -------------------------------------------------------------------------
@@ -151,7 +168,7 @@ class StreamingField(ScatteringField):
 
     @property
     def integration_rel_eps(self) -> float:
-        """ Relative integration error goal for adaptive integration
+        """Relative integration error goal for adaptive integration
 
         Relative error goal for the computation of :attr:`.C_integral`
 
@@ -172,7 +189,7 @@ class StreamingField(ScatteringField):
     # -------------------------------------------------------------------------
 
     @property
-    def C_0(self) -> np.ndarray:
+    def C_0(self) -> NDArray:
         """Container for integrals and errors :math:`C_{ml0}`
 
         (Eq. E5 - E7)
@@ -180,10 +197,10 @@ class StreamingField(ScatteringField):
         Stores the integrals and the estimated errors for the integral
         :math:`C_{ml0}`
         """
-        return self._C_0.value['integral']
+        return self._C_0.value["integral"]
 
     @property
-    def C_0_error(self) -> np.ndarray:
+    def C_0_error(self) -> NDArray:
         """Container for integrals and errors :math:`C_{ml0}`
 
         (Eq. E5 - E7)
@@ -191,12 +208,12 @@ class StreamingField(ScatteringField):
         Stores the integrals and the estimated errors for the integral
         :math:`C_{ml0}`
         """
-        return self._C_0.value['error']
+        return self._C_0.value["error"]
 
     @property
     def inf(self):
-        """Upper limit for the integration to the far-field (to infinity) [m]
-        """
+        """Limit for the integration to the far-field
+        / to infinity) [m]"""
         return self._inf.value
 
     # -------------------------------------------------------------------------
@@ -204,25 +221,33 @@ class StreamingField(ScatteringField):
     # -------------------------------------------------------------------------
 
     def _integrate_C_ml0(
-        self, kernel: Callable[[float], float],
+        self,
+        kernel: Callable[[float], float],
     ) -> (float, float):
         return integrate(
-            kernel, self.R_0, self.inf, rel_eps=self.integration_rel_eps,
+            kernel,
+            self.R_0,
+            self.inf,
+            rel_eps=self.integration_rel_eps,
         )
 
     @staticmethod
     def _compute_C_210(l: int, integral: float) -> float:
-        return - 1 / (2 * l + 1) * integral
+        return -1 / (2 * l + 1) * integral
 
     def _compute_C_210_error(self, l: int, error: float) -> float:
         return self._compute_C_210(l, error)
 
     def _compute_C_3l0(
-            self, l: int, C_2l0: float, C_5l0: float, C_6l0: float,
+        self,
+        l: int,
+        C_2l0: float,
+        C_5l0: float,
+        C_6l0: float,
     ) -> float:
         term_1 = self.V_S_r(l, self.R_0, ac=False) / (l + 1)
         term_1 += self.V_S_theta(l, self.R_0, ac=False)
-        term_1 *= self.R_0 ** l
+        term_1 *= self.R_0**l
 
         term_2 = C_2l0 / (l + 1) - C_5l0
         term_2 *= (2 * l + 1) * self.R_0 ** (2 * l - 1)
@@ -232,15 +257,23 @@ class StreamingField(ScatteringField):
         return 0.5 * (term_1 + term_2 - term_3)
 
     def _compute_C_3l0_error(
-            self, l: int, error_2l0: float, error_5l0: float, error_6l0: float,
+        self,
+        l: int,
+        error_2l0: float,
+        error_5l0: float,
+        error_6l0: float,
     ) -> float:
         term_1 = error_2l0 / (l + 1) - error_5l0
         term_1 *= (2 * l + 1) * self.R_0 ** (2 * l - 1)
-        term_2 = - (2 * l + 3) * self.R_0 ** (2 * l + 1) * error_6l0
+        term_2 = -(2 * l + 3) * self.R_0 ** (2 * l + 1) * error_6l0
         return 0.5 * term_1 - term_2
 
     def _compute_C_4l0(
-            self, l: int, C_2l0: float, C_5l0: float, C_6l0: float,
+        self,
+        l: int,
+        C_2l0: float,
+        C_5l0: float,
+        C_6l0: float,
     ) -> float:
         term_1 = (2 - l) * self.V_S_r(l, self.R_0, False) / (l * (l + 1))
         term_1 -= self.V_S_theta(l, self.R_0, ac=False)
@@ -249,13 +282,16 @@ class StreamingField(ScatteringField):
         term_2 = C_2l0 / (l + 1) - C_5l0
         term_2 *= (2 * l - 1) * self.R_0 ** (2 * l + 1)
 
-        term_3 = + (2 * l + 1) * self.R_0 ** (2 * l + 3) * C_6l0
+        term_3 = +(2 * l + 1) * self.R_0 ** (2 * l + 3) * C_6l0
 
         return 0.5 * (term_1 - term_2 + term_3)
 
     def _compute_C4l0_error(
-            self, l: int, error_2l0: float, error_5l0: float,
-            error_6l0: float,
+        self,
+        l: int,
+        error_2l0: float,
+        error_5l0: float,
+        error_6l0: float,
     ) -> float:
         term_1 = (2 * l - 1) * self.R_0 ** (2 * l + 1)
         term_1 *= error_2l0 / (l + 1) - error_5l0
@@ -273,12 +309,12 @@ class StreamingField(ScatteringField):
 
     @staticmethod
     def _compute_C_6l0(l: int, integral: float) -> float:
-        return - 1 / (2 * (2 * l + 1) * (2 * l + 3)) * integral
+        return -1 / (2 * (2 * l + 1) * (2 * l + 3)) * integral
 
     def _compute_C_6l0_error(self, l: int, error: float) -> float:
         return self._compute_C_6l0(l, error)
 
-    def _compute_C_0(self, L_max: Optional[int] = None) -> dict:
+    def _compute_C_0(self, L_max: None | int = None) -> dict:
         """Computes the integrals :math:`C_{ml0}` for :math:`l` up to `L_max`
 
         :param L_max: max index of summation
@@ -293,8 +329,8 @@ class StreamingField(ScatteringField):
         errors = np.zeros((6 + 1, self.N_max + 1))
 
         log.info(
-            'Integration to compute C_ml0 is performed. This might take '
-            'a while.',
+            "Integration to compute C_ml0 is performed. This might take "
+            "a while.",
         )
 
         for l in l_range:
@@ -335,21 +371,33 @@ class StreamingField(ScatteringField):
 
             # C_3l0
             integrals[3, l] = self._compute_C_3l0(
-                l, integrals[2, l], integrals[5, l], integrals[6, l],
+                l,
+                integrals[2, l],
+                integrals[5, l],
+                integrals[6, l],
             )
             errors[3, l] = self._compute_C_3l0_error(
-                l, error_C_2l0, error_C_5l0, error_C_6l0,
+                l,
+                error_C_2l0,
+                error_C_5l0,
+                error_C_6l0,
             )
 
             # C_4l0
             integrals[4, l] = self._compute_C_4l0(
-                l, integrals[2, l], integrals[5, l], integrals[6, l],
+                l,
+                integrals[2, l],
+                integrals[5, l],
+                integrals[6, l],
             )
             errors[4, l] = self._compute_C4l0_error(
-                l, error_C_2l0, error_C_5l0, error_C_6l0,
+                l,
+                error_C_2l0,
+                error_C_5l0,
+                error_C_6l0,
             )
 
-        return {'integral': integrals, 'error': errors}
+        return {"integral": integrals, "error": errors}
 
     def _compute_inf(self) -> float:
         if self.inf_type is None:
@@ -357,18 +405,18 @@ class StreamingField(ScatteringField):
                 return self.inf_factor * self.R_0
             else:
                 return self.inf_factor * self.delta
-        elif self.inf_type == 'delta':
+        elif self.inf_type == "delta":
             return self.inf_factor * self.delta
-        elif self.inf_type == 1 or self.inf_type == '1':
+        elif self.inf_type == 1 or self.inf_type == "1":
             return self.inf_factor
-        elif self.inf_type == 'radius':
+        elif self.inf_type == "radius":
             return self.inf_factor * self.R_0
         else:
             raise ValueError(
                 f"inf_type needs to be 'boundary layer', '1', "
                 f"'radius'"
-                f'\n '
-                f'got: {self.inf_type}',
+                f"\n "
+                f"got: {self.inf_type}",
             )
 
     # -------------------------------------------------------------------------
@@ -388,7 +436,7 @@ class StreamingField(ScatteringField):
         gamma = self.gamma(l, r, ac)
         d_gamma = self.d_gamma(l, r, ac)
         beta = self.beta(l, r, ac)
-        return - self.rho_f / (self.eta_f * r) * (gamma + r * d_gamma - beta)
+        return -self.rho_f / (self.eta_f * r) * (gamma + r * d_gamma - beta)
 
     def F(self, n: int, m: int, r: float, ac: bool) -> complex:
         """:math:`F_{mn}(r)`
@@ -402,7 +450,7 @@ class StreamingField(ScatteringField):
         :return: F(n, m, r)
         """
         sc = not ac
-        factor = 1j * conj(self.k_f ** 2) / r
+        factor = 1j * conj(self.k_f**2) / r
         term_1 = 2 * self.phi(n, r, sc, True).conjugate()
         term_1 += r * self.d_phi(n, r, sc, True).conjugate()
         term_1 *= self.V_r(m, r, sc, True)
@@ -423,7 +471,7 @@ class StreamingField(ScatteringField):
         :return: G(m, n, r)
         """
         sc = not ac
-        factor = 1j * conj(self.k_f ** 2) / r
+        factor = 1j * conj(self.k_f**2) / r
         phi = self.phi(n, r, sc, True)
         v_theta = self.V_theta(m, r, sc, True)
 
@@ -443,13 +491,13 @@ class StreamingField(ScatteringField):
             cg_1 = cg(l, 0, j, 0, i, 0)
             if not cg_1:
                 return 0
-            return cg_1 ** 2 / (2 * i + 1) * conj(self.d_V_r(i, r, sc, True))
+            return cg_1**2 / (2 * i + 1) * conj(self.d_V_r(i, r, sc, True))
 
         def second_inner_term(i: int, j: int, h: int) -> complex:
             cg_coef = cg(l, 0, j - 2 * i + 1, 0, h, 0)
             if not cg_coef:
                 return 0
-            factor_1 = (2 * j - 4 * i + 3) * cg_coef ** 2 / (2 * h + 1)
+            factor_1 = (2 * j - 4 * i + 3) * cg_coef**2 / (2 * h + 1)
             factor_2 = self.V_theta(j, r, sc, True) / r
             term_1 = (h + 1) * (h + 2) / (2 * h + 3)
             term_1 *= self.V_r(h + 1, r, sc, True).conjugate()
@@ -474,16 +522,21 @@ class StreamingField(ScatteringField):
         for n in self.range_1_N_max:
             for m in full_range(1, int((n + 1) / 2)):
                 for k in full_range(
-                        abs(l - (n - 2 * m + 1)), l + n - 2 * m + 1,
+                    abs(l - (n - 2 * m + 1)),
+                    l + n - 2 * m + 1,
                 ):
                     second_sum += second_inner_term(m, n, k)
         return (
-            (2 * l + 1) / (2 * self.omega)
+            (2 * l + 1)
+            / (2 * self.omega)
             * (1j * (first_sum + second_sum)).real
         )
 
     def V_S_theta(
-            self, l: int, r: float, ac: bool,
+        self,
+        l: int,
+        r: float,
+        ac: bool,
     ) -> float:
         """:math:`V_{S \\theta l}(r)`
 
@@ -502,7 +555,7 @@ class StreamingField(ScatteringField):
             term_1 *= self.d_V_theta(i, r, sc, True).conjugate()
 
             term_2 = self.V_r(j, r, sc, True)
-            term_2 -= j ** 2 * self.V_theta(j, r, sc, True)
+            term_2 -= j**2 * self.V_theta(j, r, sc, True)
 
             term_2 = self.V_theta(i, r, sc, True) * term_2.conjugate() / r
 
@@ -522,22 +575,23 @@ class StreamingField(ScatteringField):
                     first_sum += first_inner_term(m, n)
         second_sum = self._V_S_theta_second_sum(l, r, ac)
         return (
-            (2 * l + 1) / (2 * self.omega * sqrt(l * (l + 1)))
+            (2 * l + 1)
+            / (2 * self.omega * sqrt(l * (l + 1)))
             * (1j * (first_sum + second_sum)).real
         )
 
     def _V_S_theta_second_sum(self, l: int, r: float, ac: bool) -> complex:
-
         def second_inner_term(i: int, j: int, h: int) -> complex:
             cg_1 = cg(j - 2 * i, 0, l, 0, h, 0)
             cg_2 = cg(j - 2 * i, 0, l, 1, h, 1)
             if not (h >= 1 and cg_1 and cg_2):
                 return 0
             else:
-                factor_1 = (2 * j - 4 * i + 1)
+                factor_1 = 2 * j - 4 * i + 1
                 factor_2 = sqrt(h * (h + 1)) * cg_1 * cg_2 / (2 * h + 1)
                 V_theta = self.V_theta(h, r, sc, True)
                 return factor_1 * factor_2 * V_theta
+
         # Early return
         if l == 0:
             return 0
@@ -571,7 +625,7 @@ class StreamingField(ScatteringField):
             cg_1 = cg(l, 0, j, 0, i, 0)
             if not cg_1:
                 return 0
-            factor = cg_1 ** 2 / (2 * i + 1)
+            factor = cg_1**2 / (2 * i + 1)
             F = self.F(j, i, r, ac)
             G = self.G(j, i, r, ac)
             return factor * (F - i * (i + 1) * G)
@@ -580,7 +634,7 @@ class StreamingField(ScatteringField):
             cg_1 = cg(l, 0, j - 2 * i + 1, 0, h, 0)
             if not cg_1:
                 return 0
-            factor = (2 * j - 4 * i + 3) * cg_1 ** 2 / (2 * h + 1)
+            factor = (2 * j - 4 * i + 3) * cg_1**2 / (2 * h + 1)
             term_1 = (h + 1) * (h + 2) / (2 * h + 3)
             term_1 *= self.G(j, h + 1, r, ac)
             if h <= 1:
@@ -600,8 +654,8 @@ class StreamingField(ScatteringField):
         for n in self.range_1_N_max:
             for m in full_range(1, int((n + 1) / 2)):
                 for k in full_range(
-                        abs(l - (n - 2 * m + 1)),
-                        l + n - 2 * m + 1,
+                    abs(l - (n - 2 * m + 1)),
+                    l + n - 2 * m + 1,
                 ):
                     second_sum += second_term(m, n, k)
 
@@ -622,16 +676,16 @@ class StreamingField(ScatteringField):
             cg_1 = cg(l, 0, j, 0, i, 0)
             if not cg_1:
                 return 0
-            factor = cg_1 ** 2 / (2 * i + 1) * self.V_r(j, r, sc, True)
+            factor = cg_1**2 / (2 * i + 1) * self.V_r(j, r, sc, True)
             d_V_r = self.d_V_r(i, r, sc, True)
             phi = self.phi(i, r, sc, True)
-            return (factor * (d_V_r - self.k_f ** 2 * phi).conjugate()).real
+            return (factor * (d_V_r - self.k_f**2 * phi).conjugate()).real
 
         def second_term(i: int, j: int, h: int) -> complex:
             cg_1 = cg(l, 0, j - 2 * i + 1, 0, h, 0)
             if not cg_1:
                 return 0
-            factor = cg_1 ** 2 / (2 * h + 1)
+            factor = cg_1**2 / (2 * h + 1)
             term_1 = self.V_r(h + 1, r, sc, True)
             term_1 -= self.V_theta(h + 1, r, sc, True)
             term_1 = (h + 1) * (h + 2) / (2 * h + 3) * term_1.conjugate()
@@ -659,11 +713,11 @@ class StreamingField(ScatteringField):
             for m in full_range(1, int((n + 1) / 2)):
                 second_inner_sum = complex(0)
                 for k in full_range(
-                        abs(l - (n - 2 * m + 1)),
-                        l + n - 2 * m + 1,
+                    abs(l - (n - 2 * m + 1)),
+                    l + n - 2 * m + 1,
                 ):
                     second_inner_sum += second_term(m, n, k)
-                second_inner_sum *= (2 * n - 4 * m + 3)
+                second_inner_sum *= 2 * n - 4 * m + 3
                 second_inner_sum *= self.V_theta(n, r, sc, True) / r
                 second_sum += second_inner_sum.real
         return (2 * l + 1) / 2 * (first_sum + second_sum)
@@ -691,14 +745,14 @@ class StreamingField(ScatteringField):
             term_1 *= self.d_V_theta(i, r, sc, True).conjugate()
 
             term_2 = self.V_r(j, r, sc, True) / r
-            term_2 -= j ** 2 * self.V_theta(j, r, sc, True) / r
-            term_2 -= self.k_f ** 2 * self.phi(j, r, sc, True)
+            term_2 -= j**2 * self.V_theta(j, r, sc, True) / r
+            term_2 -= self.k_f**2 * self.phi(j, r, sc, True)
             term_2 = self.V_theta(i, r, sc, True) * term_2.conjugate()
 
             return factor * (term_1 + term_2).real
 
         if l == 0:
-            raise ValueError('gamma for n=0 is not defined')
+            raise ValueError("gamma for n=0 is not defined")
 
         sc = not ac
 
@@ -709,10 +763,7 @@ class StreamingField(ScatteringField):
                 if m >= 1:
                     first_sum += first_term(m, n)
         second_sum = self._V_S_theta_second_sum(l, r, ac).real
-        return (
-            (2 * l + 1) / (2 * sqrt(l * (l + 1)))
-            * (first_sum + second_sum)
-        )
+        return (2 * l + 1) / (2 * sqrt(l * (l + 1))) * (first_sum + second_sum)
 
     def d_gamma(self, l: int, r: float, ac: bool) -> float:
         """:math:`\\partial_r \\gamma_l(r)`
@@ -738,15 +789,15 @@ class StreamingField(ScatteringField):
             term_2 *= self.d2_V_theta(i, r, sc, True).conjugate()
 
             term_3 = self.V_r(j, r, sc, True) / r
-            term_3 -= j ** 2 * self.V_theta(j, r, sc, True) / r
-            term_3 -= self.k_f ** 2 * self.phi(j, r, sc, True)
+            term_3 -= j**2 * self.V_theta(j, r, sc, True) / r
+            term_3 -= self.k_f**2 * self.phi(j, r, sc, True)
             term_3 = self.d_V_theta(i, r, sc, True) * term_3.conjugate()
 
             term_4 = self.d_V_r(j, r, sc, True) / r
-            term_4 -= j ** 2 * self.d_V_theta(j, r, sc, True) / r
-            term_4 -= self.V_r(j, r, sc, True) / r ** 2
-            term_4 += j ** 2 * self.V_theta(j, r, sc, True) / r ** 2
-            term_4 -= self.k_f ** 2 * self.d_phi(j, r, sc, True)
+            term_4 -= j**2 * self.d_V_theta(j, r, sc, True) / r
+            term_4 -= self.V_r(j, r, sc, True) / r**2
+            term_4 += j**2 * self.V_theta(j, r, sc, True) / r**2
+            term_4 -= self.k_f**2 * self.d_phi(j, r, sc, True)
             term_4 = self.V_theta(i, r, sc, True) * term_4.conjugate()
 
             return (factor * (term_1 + term_2 + term_3 + term_4)).real
@@ -764,12 +815,12 @@ class StreamingField(ScatteringField):
             term_2 *= self.d_V_theta(h, r, sc, True) / r
 
             term_3 = self.V_theta(j, r, sc, True).conjugate()
-            term_3 *= self.V_theta(h, r, sc, True) / r ** 2
+            term_3 *= self.V_theta(h, r, sc, True) / r**2
 
             return (factor * (term_1 + term_2 - term_3)).real
 
         if l == 0:
-            raise ValueError('d_gamma for n=0 is not defined')
+            raise ValueError("d_gamma for n=0 is not defined")
 
         sc = not ac
 
@@ -790,9 +841,8 @@ class StreamingField(ScatteringField):
                         second_inner_sum += second_term(m, n, k)
                 second_sum += (2 * n - 4 * m + 1) * second_inner_sum
 
-        return ((2 * l + 1) / (2 * sqrt(l * (l + 1)))
-                * (first_sum + second_sum))
+        return (2 * l + 1) / (2 * sqrt(l * (l + 1))) * (first_sum + second_sum)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
