@@ -1,4 +1,4 @@
-from typing import Optional, Union
+from __future__ import annotations
 
 import numpy as np
 
@@ -17,6 +17,8 @@ from osaft.solutions.base_scattering import (
 )
 from osaft.solutions.king1934.base import BaseKing
 
+NDArray = np.ndarray
+
 
 class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
     """Scattering field class for King (1934)
@@ -33,27 +35,38 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
     """
 
     def __init__(
-        self, f: Union[Frequency, float, int],
-        R_0: Union[Sphere, float, int],
+        self,
+        f: Frequency | float | int,
+        R_0: Sphere | float | int,
         rho_s: float,
-        rho_f: float, c_f: float,
-        p_0: float, wave_type: WaveType, position: Optional[float] = None,
+        rho_f: float,
+        c_f: float,
+        p_0: float,
+        wave_type: WaveType,
+        position: None | float = None,
         N_max: int = 5,
     ) -> None:
-        """Constructor method
-        """
+        """Constructor method"""
 
         # init of parent class
         BaseKing.__init__(
-            self, f, R_0, rho_s, rho_f, c_f, p_0,
-            wave_type, position,
+            self,
+            f,
+            R_0,
+            rho_s,
+            rho_f,
+            c_f,
+            p_0,
+            wave_type,
+            position,
         )
         BaseScattering.__init__(self, N_max)
 
         # Dependent variables
-        self._A_dash_n = ActiveListVariable(self._compute_A_dash_n, 'A_dash_n')
+        self._A_dash_n = ActiveListVariable(self._compute_A_dash_n, "A_dash_n")
         self._A_dash_n.is_computed_by(
-            self.field._A_in, self._alpha,
+            self.field._A_in,
+            self._alpha,
             self._rho_tilde,
         )
         if type(self) is ScatteringField:
@@ -62,54 +75,70 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
 
     def __repr__(self):
         return (
-            f'{type(self)}(f={self.f}, R_0={self.R_0}, '
-            f'rho_s={self.rho_s}, rho_f={self.rho_f}, c_f={self.c_f}, '
-            f'p_0={self.p_0}, position={self.position}, '
-            f'wave_type={self.wave_type}, N_max={self.N_max})'
+            f"{type(self)}(f={self.f}, R_0={self.R_0}, "
+            f"rho_s={self.rho_s}, rho_f={self.rho_f}, c_f={self.c_f}, "
+            f"p_0={self.p_0}, position={self.position}, "
+            f"wave_type={self.wave_type}, N_max={self.N_max})"
         )
 
     def __str__(self):
-        out = 'King\'s solution to the Scattering field'
-        out += ' with following properties: \n'
-        out += SF.get_str_text('Wave type', '', self.wave_type, '')
-        out += SF.get_str_text('Frequency', 'f', self.f, 'Hz')
-        out += SF.get_str_text('Pressure', 'p_0', self.p_0, 'Pa')
+        out = "King's solution to the Scattering field"
+        out += " with following properties: \n"
+        out += SF.get_str_text("Wave type", "", self.wave_type, "")
+        out += SF.get_str_text("Frequency", "f", self.f, "Hz")
+        out += SF.get_str_text("Pressure", "p_0", self.p_0, "Pa")
         out += SF.get_str_text(
-            'Position', 'd',
-            self.position, 'rad',
+            "Position",
+            "d",
+            self.position,
+            "rad",
         )
         out += SF.get_str_text(
-            'Wavelength', 'lambda',
-            self.field.lambda_f, 'm',
+            "Wavelength",
+            "lambda",
+            self.field.lambda_f,
+            "m",
         )
 
-        out += 'Fluid\n'
+        out += "Fluid\n"
         out += SF.get_str_text(
-            'Density', 'rho_f',
-            self.rho_f, 'kg/m^3',
+            "Density",
+            "rho_f",
+            self.rho_f,
+            "kg/m^3",
         )
         out += SF.get_str_text(
-            'Sound Speed', 'c_0',
-            self.c_f, 'm/s',
+            "Sound Speed",
+            "c_0",
+            self.c_f,
+            "m/s",
         )
         out += SF.get_str_text(
-            'Compressibility', 'kappa_f',
-            self.kappa_f, '1/Pa',
+            "Compressibility",
+            "kappa_f",
+            self.kappa_f,
+            "1/Pa",
         )
 
-        out += 'Particle\n'
+        out += "Particle\n"
         out += SF.get_str_text(
-            'Radius', 'R_0',
-            self.R_0, 'm',
+            "Radius",
+            "R_0",
+            self.R_0,
+            "m",
         )
         out += SF.get_str_text(
-            'Density', 'rho_s',
-            self.rho_s, 'kg/m^3',
+            "Density",
+            "rho_s",
+            self.rho_s,
+            "kg/m^3",
         )
-        out += 'Other\n'
+        out += "Other\n"
         out += SF.get_str_text(
-            '#modes', 'N_max',
-            self.N_max, None,
+            "#modes",
+            "N_max",
+            self.N_max,
+            None,
         )
         return out
 
@@ -127,9 +156,9 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         :param t: time [s]
         """
 
-        out = exp(- 1j * self.omega * t) * self.A_in(1) / self.alpha ** 3
+        out = exp(-1j * self.omega * t) * self.A_in(1) / self.alpha**3
         out *= self.k_f / self.rho_tilde
-        out /= (self.F_n(1, self.alpha) - 1j * self.G_n(1, self.alpha))
+        out /= self.F_n(1, self.alpha) - 1j * self.G_n(1, self.alpha)
         return out
 
     # -----------------------------------------------------
@@ -148,7 +177,7 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         :param n: mode
         :param arg: argument for spherical Bessel function
         """
-        return - Bf.bessely(n, arg) * arg ** (- n)
+        return -Bf.bessely(n, arg) * arg ** (-n)
 
     @staticmethod
     def psi_n(n: int, arg: float) -> complex:
@@ -159,7 +188,7 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         :param n: mode
         :param arg: argument for spherical Bessel function
         """
-        return Bf.besselj(n, arg) * arg ** (- n)
+        return Bf.besselj(n, arg) * arg ** (-n)
 
     def F_n(self, n: int, arg: float) -> float:
         """From King equation (30) and (31)
@@ -169,7 +198,7 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         :param n: mode
         :param arg: argument for spherical Bessel function
         """
-        out = self.alpha ** 2 * self.phi_n(n + 1, arg)
+        out = self.alpha**2 * self.phi_n(n + 1, arg)
         if n == 1:
             out -= (1 - 1 / self.rho_tilde) * self.phi_n(n, arg)
         else:
@@ -185,7 +214,7 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         :param n: mode
         :param arg: argument for spherical Bessel function
         """
-        out = self.alpha ** 2 * self.psi_n(n + 1, arg)
+        out = self.alpha**2 * self.psi_n(n + 1, arg)
         if n == 1:
             out -= (1 - 1 / self.rho_tilde) * self.psi_n(n, arg)
         else:
@@ -204,8 +233,8 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         return self._A_dash_n.item(n)
 
     def _compute_A_dash_n(self, n: int) -> complex:
-        out = - self.A_in(n) * self.G_n(n, self.alpha)
-        out /= (self.G_n(n, self.alpha) + 1j * self.F_n(n, self.alpha))
+        out = -self.A_in(n) * self.G_n(n, self.alpha)
+        out /= self.G_n(n, self.alpha) + 1j * self.F_n(n, self.alpha)
         return out
 
     # -----------------------------------------------------
@@ -214,9 +243,9 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
 
     def Phi_scattering(
         self,
-        r: Union[float, np.ndarray, list[float]],
-        theta: Union[float, np.ndarray, list[float]],
-        t: Union[float, np.ndarray, list[float]],
+        r: float | NDArray | list[float],
+        theta: float | NDArray | list[float],
+        t: float | NDArray | list[float],
     ) -> complex:
         r"""King equation (28) for scattering potential
         :math:`\Phi_{\mathrm{scattering}}`
@@ -225,8 +254,9 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         :param theta: tangential coordinate [rad]
         :param t: time [s]
         """
+
         def Phi_n(n: int):
-            num = - self.G_n(n, self.alpha)
+            num = -self.G_n(n, self.alpha)
             num *= self.A_in(n) * Bf.hankelh2(n, r * self.k_f)
             denom = self.G_n(n, self.alpha)
             denom += 1j * self.F_n(n, self.alpha)
@@ -243,9 +273,9 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
 
     def Phi_incident(
         self,
-        r: Union[float, np.ndarray, list[float]],
-        theta: Union[float, np.ndarray, list[float]],
-        t: Union[float, np.ndarray, list[float]],
+        r: float | NDArray | list[float],
+        theta: float | NDArray | list[float],
+        t: float | NDArray | list[float],
     ) -> complex:
         r"""King equation (28) for scattering potential
         :math:`\Phi_{\mathrm{incident}}`
@@ -254,6 +284,7 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         :param theta: tangential coordinate [rad]
         :param t: time [s]
         """
+
         def Phi_n(n: int):
             coefficient = self.A_in(n) * Bf.besselj(n, r * self.k_f)
             out = exp(-1j * self.omega * t)
@@ -266,8 +297,9 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         return out
 
     def V_r_sc(
-        self, n: int,
-        r: Union[float, np.ndarray, list[float]],
+        self,
+        n: int,
+        r: float | NDArray | list[float],
     ) -> complex:
         """Implements :meth:`osaft.solutions.base_scattering.BaseScattering.\
 V_r_sc`
@@ -275,8 +307,9 @@ V_r_sc`
         return self.A_dash_n(n) * self.k_f * Bf.d1_hankelh2(n, self.k_f * r)
 
     def V_theta_sc(
-        self, n: int,
-        r: Union[float, np.ndarray, list[float]],
+        self,
+        n: int,
+        r: float | NDArray | list[float],
     ) -> complex:
         """Implements :meth:`osaft.solutions.base_scattering.BaseScattering.\
 V_theta_sc`
@@ -284,5 +317,5 @@ V_theta_sc`
         return self.A_dash_n(n) * Bf.hankelh2(n, self.k_f * r) / r
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     pass
