@@ -2,11 +2,12 @@ from abc import abstractmethod
 
 from osaft import WaveType
 from osaft.core.backgroundfields import WrongWaveTypeError
+from osaft.tests.testing_parameters import RandomParameters
 
 
 class HelperARF:
-    """Baseclass for testing the ARF computation
-    """
+    """Baseclass for testing the ARF computation"""
+
     _threshold = 1e-12
 
     @abstractmethod
@@ -14,13 +15,14 @@ class HelperARF:
         pass
 
     def test_wrong_wave_type_error(self):
-        WaveType.WRONGWAVETYPE = 3, 'wrong wave type'
+        WaveType.WRONGWAVETYPE = 3, "wrong wave type"
         self.cls.wave_type = WaveType.WRONGWAVETYPE
         self.assertRaises(WrongWaveTypeError, self.cls.compute_arf)
 
     def test_arf(self) -> None:
         self.do_testing(
-            self.compute_arf, self.cls.compute_arf,
+            self.compute_arf,
+            self.cls.compute_arf,
             threshold=self._threshold,
             zero=1e-30,
         )
@@ -28,18 +30,22 @@ class HelperARF:
 
 class HelperStandingARF(HelperARF):
 
+    parameters: RandomParameters
+
     def test_arf(self) -> None:
-        self.wave_type = WaveType.STANDING
-        self._wave_type.list_of_values = [self.wave_type]
+        self.parameters.wave_type = WaveType.STANDING
+        self.parameters._wave_type.list_of_values = [WaveType.STANDING]
         HelperARF.test_arf(self)
 
 
 class HelperTravelingARF(HelperARF):
 
+    parameters: RandomParameters
+
     def test_arf(self) -> None:
 
-        self.wave_type = WaveType.TRAVELLING
-        self._wave_type.list_of_values = [self.wave_type]
+        self.parameters.wave_type = WaveType.TRAVELLING
+        self.parameters._wave_type.list_of_values = [WaveType.TRAVELLING]
         HelperARF.test_arf(self)
 
 
