@@ -6,7 +6,6 @@ from osaft.core.warnings import AssumptionWarning, raise_assumption_warning
 
 
 class TestCustomWarnings(unittest.TestCase):
-
     def test_AssumptionWarning(self) -> None:
         for _ in np.arange(5):
             val = np.random.randint(0, 100) * np.random.random_sample()
@@ -17,5 +16,5 @@ class TestCustomWarnings(unittest.TestCase):
                 raise_assumption_warning(val <= 1.1 * val)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
